@@ -99,6 +99,7 @@ CSG_String Get_Info(int i)
 #include "milankovic.h"
 #include "etp_hargreave.h"
 #include "daily_sun.h"
+#include "bioclimatic_vars.h"
 
 
 //---------------------------------------------------------
@@ -122,8 +123,10 @@ CSG_Module *		Create_Module(int i)
 
 	case  9:	return( new CDaily_Sun );
 
+	case 10:	return( new CBioclimatic_Vars );
+
 	//-----------------------------------------------------
-	case 10:	return( NULL );
+	case 11:	return( NULL );
 	default:	return( MLB_INTERFACE_SKIP_MODULE );
 	}
 }
