@@ -465,7 +465,7 @@ CExecute_SQL::CExecute_SQL(void)
 	));
 
 	Parameters.Add_String(
-		NULL	, "SQL"			, _TL("SQL Statment"),
+		NULL	, "SQL"			, _TL("SQL Statement"),
 		_TL(""),
 		SG_T("CREATE TABLE myTable1 (Col1 VARCHAR(255) PRIMARY KEY, Col2 INTEGER);\n")
 		SG_T("INSERT INTO myTable1 (Col1, Col2) VALUES(\'First Value\', 1);\n")
