@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Filter.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -35,7 +35,7 @@
 // You should have received a copy of the GNU General    //
 // Public License along with this program; if not,       //
 // write to the Free Software Foundation, Inc.,          //
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307,   //
+// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
 // USA.                                                  //
 //                                                       //
 //-------------------------------------------------------//
@@ -90,18 +90,18 @@ public:
 
 protected:
 
-	virtual bool			On_Execute		(void);
+	virtual bool			On_Before_Execution		(void);
+	virtual bool			On_Execute				(void);
 
 
 private:
 
-	CSG_Grid_Radius			m_Radius;
+	CSG_Grid_Cell_Addressor	m_Kernel;
 
 	CSG_Grid				*m_pInput;
 
 
-	double					Get_Mean_Square	(int x, int y, int Radius);
-	double					Get_Mean_Circle	(int x, int y);
+	bool					Get_Mean		(int x, int y, double &Value);
 
 };
 
