@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id: delaunay.c 911 2011-02-14 16:38:15Z reklov_w $
- *********************************************************/
 /******************************************************************************
  *
  * File:           delaunay.c
@@ -15,16 +12,18 @@
  * Description:    None
  *
  * Revisions:      10/06/2003 PS: delaunay_build(); delaunay_destroy();
- *                 struct delaunay: from now on, only shallow copy of the
- *                 input data is contained in struct delaunay. This saves
- *                 memory and is consistent with libcsa.
- *
- * Modified:       Joao Cardoso, 4/2/2003
- *                 Adapted for use with Qhull instead of "triangle".
+ *                   struct delaunay: from now on, only shallow copy of the
+ *                   input data is contained in struct delaunay. This saves
+ *                   memory and is consistent with libcsa.
+ *                 30/10/2007 PS: added delaunay_addflag() and
+ *                   delaunay_resetflags(); modified delaunay_circles_find()
+ *                   to reset the flags to 0 on return. This is very important
+ *                   for large datasets, many thanks to John Gerschwitz,
+ *                   Petroleum Geo-Services, for identifying the problem.
  *
  *****************************************************************************/
 
-//#define USE_QHULL
+#define ANSI_DECLARATORS        /* for triangle.h */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -33,23 +32,57 @@
 #include <string.h>
 #include <limits.h>
 #include <float.h>
-#ifdef USE_QHULL
-#include <qhull/qhull_a.h>
-#else
-#include "triangle.h"
-#endif
 #include "istack.h"
 #include "nan.h"
 #include "delaunay.h"
+#include "nn.h"
+#include "nn_internal.h"
 
-int circle_build(circle* c, point* p0, point* p1, point* p2);
-int circle_contains(circle* c, point* p);
+/*
+ * This parameter is used in search of tricircles containing a given point:
+ *   if there are no more triangles than N_SEARCH_TURNON
+ *     do linear search
+ *   else
+ *     do more complicated stuff
+ */
+#define N_SEARCH_TURNON 20
+#define N_FLAGS_TURNON 1000
+#define N_FLAGS_INC 100
 
-#ifdef USE_QHULL
-static int cw(delaunay *d, triangle *t);
-#endif
+static delaunay* delaunay_create()
+{
+    delaunay* d = malloc(sizeof(delaunay));
 
+    d->npoints = 0;
+    d->points = NULL;
+    d->xmin = DBL_MAX;
+    d->xmax = -DBL_MAX;
+    d->ymin = DBL_MAX;
+    d->ymax = -DBL_MAX;
+    d->ntriangles = 0;
+    d->triangles = NULL;
+    d->circles = NULL;
+    d->neighbours = NULL;
+    d->n_point_triangles = NULL;
+    d->point_triangles = NULL;
+    d->nedges = 0;
+    d->edges = NULL;
+    d->flags = NULL;
+    d->first_id = -1;
+    d->t_in = NULL;
+    d->t_out = NULL;
+    d->nflags = 0;
+    d->nflagsallocated = 0;
+    d->flagids = NULL;
+
+    return d;
+}
+
+//---------------------------------------------------------
 #ifndef USE_QHULL
+
+#include "triangle.h"
+
 static void tio_init(struct triangulateio* tio)
 {
     tio->pointlist = NULL;
@@ -109,32 +142,6 @@ static void tio_destroy(struct triangulateio* tio)
         free(tio->normlist);
 }
 
-static delaunay* delaunay_create()
-{
-    delaunay* d = (delaunay *)malloc(sizeof(delaunay));
-
-    d->npoints = 0;
-    d->points = NULL;
-    d->xmin = DBL_MAX;
-    d->xmax = -DBL_MAX;
-    d->ymin = DBL_MAX;
-    d->ymax = -DBL_MAX;
-    d->ntriangles = 0;
-    d->triangles = NULL;
-    d->circles = NULL;
-    d->neighbours = NULL;
-    d->n_point_triangles = NULL;
-    d->point_triangles = NULL;
-    d->nedges = 0;
-    d->edges = NULL;
-    d->flags = NULL;
-    d->first_id = -1;
-    d->t_in = NULL;
-    d->t_out = NULL;
-
-    return d;
-}
-
 static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
 {
     int i, j;
@@ -171,12 +178,12 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
 
     d->ntriangles = tio_out->numberoftriangles;
     if (d->ntriangles > 0) {
-        d->triangles = (triangle *)malloc(d->ntriangles * sizeof(triangle));
-        d->neighbours = (triangle_neighbours *)malloc(d->ntriangles * sizeof(triangle_neighbours));
-        d->circles = (circle *)malloc(d->ntriangles * sizeof(circle));
-        d->n_point_triangles = (int *)calloc(d->npoints, sizeof(int));
-        d->point_triangles = (int **)malloc(d->npoints * sizeof(int*));
-        d->flags = (int *)calloc(d->ntriangles, sizeof(int));
+        d->triangles = malloc(d->ntriangles * sizeof(triangle));
+        d->neighbours = malloc(d->ntriangles * sizeof(triangle_neighbours));
+        d->circles = malloc(d->ntriangles * sizeof(circle));
+        d->n_point_triangles = calloc(d->npoints, sizeof(int));
+        d->point_triangles = malloc(d->npoints * sizeof(int*));
+        d->flags = calloc(d->ntriangles, sizeof(int));
     }
 
     if (nn_verbose)
@@ -186,6 +193,7 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
         triangle* t = &d->triangles[i];
         triangle_neighbours* n = &d->neighbours[i];
         circle* c = &d->circles[i];
+        int status;
 
         t->vids[0] = tio_out->trianglelist[offset];
         t->vids[1] = tio_out->trianglelist[offset + 1];
@@ -195,7 +203,8 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
         n->tids[1] = tio_out->neighborlist[offset + 1];
         n->tids[2] = tio_out->neighborlist[offset + 2];
 
-        circle_build(c, &d->points[t->vids[0]], &d->points[t->vids[1]], &d->points[t->vids[2]]);
+        status = circle_build1(c, &d->points[t->vids[0]], &d->points[t->vids[1]], &d->points[t->vids[2]]);
+        assert(status);
 
         if (nn_verbose)
             fprintf(stderr, "  %d: (%d,%d,%d)\n", i, t->vids[0], t->vids[1], t->vids[2]);
@@ -210,7 +219,7 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
     if (d->ntriangles > 0) {
         for (i = 0; i < d->npoints; ++i) {
             if (d->n_point_triangles[i] > 0)
-                d->point_triangles[i] = (int *)malloc(d->n_point_triangles[i] * sizeof(int));
+                d->point_triangles[i] = malloc(d->n_point_triangles[i] * sizeof(int));
             else
                 d->point_triangles[i] = NULL;
             d->n_point_triangles[i] = 0;
@@ -229,11 +238,10 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
 
     if (tio_out->edgelist != NULL) {
         d->nedges = tio_out->numberofedges;
-        d->edges = (int *)malloc(d->nedges * 2 * sizeof(int));
+        d->edges = malloc(d->nedges * 2 * sizeof(int));
         memcpy(d->edges, tio_out->edgelist, d->nedges * 2 * sizeof(int));
     }
 }
-#endif
 
 /* Builds Delaunay triangulation of the given array of points.
  *
@@ -246,7 +254,6 @@ static void tio2delaunay(struct triangulateio* tio_out, delaunay* d)
  * @return Delaunay triangulation structure with triangulation results
  */
 delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh, double holes[])
-#ifndef USE_QHULL
 {
     delaunay* d = delaunay_create();
     struct triangulateio tio_in;
@@ -263,7 +270,7 @@ delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh,
         return NULL;
     }
 
-    tio_in.pointlist = (double *)malloc(np * 2 * sizeof(double));
+    tio_in.pointlist = malloc(np * 2 * sizeof(double));
     tio_in.numberofpoints = np;
     for (i = 0, j = 0; i < np; ++i) {
         tio_in.pointlist[j++] = points[i].x;
@@ -271,13 +278,13 @@ delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh,
     }
 
     if (ns > 0) {
-        tio_in.segmentlist = (int *)malloc(ns * 2 * sizeof(int));
+        tio_in.segmentlist = malloc(ns * 2 * sizeof(int));
         tio_in.numberofsegments = ns;
         memcpy(tio_in.segmentlist, segments, ns * 2 * sizeof(int));
     }
 
     if (nh > 0) {
-        tio_in.holelist = (double *)malloc(nh * 2 * sizeof(double));
+        tio_in.holelist = malloc(nh * 2 * sizeof(double));
         tio_in.numberofholes = nh;
         memcpy(tio_in.holelist, holes, nh * 2 * sizeof(double));
     }
@@ -312,9 +319,25 @@ delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh,
 
     return d;
 }
+
+//---------------------------------------------------------
 #else /* USE_QHULL */
+
+#include <qhull/qhull_a.h>
+
+/* returns 1 if a,b,c are clockwise ordered */
+static int cw(delaunay *d, triangle *t)
 {
-  delaunay* d = (delaunay *)malloc(sizeof(delaunay));
+  point* pa = &d->points[t->vids[0]];
+  point* pb = &d->points[t->vids[1]];
+  point* pc = &d->points[t->vids[2]];
+
+  return ((pb->x - pa->x)*(pc->y - pa->y) < (pc->x - pa->x)*(pb->y - pa->y));
+}
+
+delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh, double holes[])
+{
+  delaunay* d = delaunay_create();
 
   coordT *qpoints;                     /* array of coordinates for each point */
   boolT ismalloc = False;              /* True if qhull should free points */
@@ -459,7 +482,7 @@ delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh,
 	  n->tids[2] = tmp;
 	}
 
-	circle_build(c, &d->points[t->vids[0]], &d->points[t->vids[1]],
+	circle_build1(c, &d->points[t->vids[0]], &d->points[t->vids[1]],
 		     &d->points[t->vids[2]]);
 
 	if (nn_verbose)
@@ -521,21 +544,10 @@ delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh,
 
   return d;
 }
+#endif /* USE_QHULL */
 
- /* returns 1 if a,b,c are clockwise ordered */
-static int cw(delaunay *d, triangle *t)
-{
-  point* pa = &d->points[t->vids[0]];
-  point* pb = &d->points[t->vids[1]];
-  point* pc = &d->points[t->vids[2]];
 
-  return ((pb->x - pa->x)*(pc->y - pa->y) <
-	  (pc->x - pa->x)*(pb->y - pa->y));
-}
-
-#endif
-
-/* Releases memory engaged in the Delaunay triangulation structure.
+/* Destroys Delaunay triangulation.
  *
  * @param d Structure to be destroyed
  */
@@ -574,12 +586,14 @@ void delaunay_destroy(delaunay* d)
         istack_destroy(d->t_in);
     if (d->t_out != NULL)
         istack_destroy(d->t_out);
+    if (d->flagids != NULL)
+        free(d->flagids);
     free(d);
 }
 
 /* Returns whether the point p is on the right side of the vector (p0, p1).
  */
-static int on_right_side(point* p, point* p0, point* p1)
+static int onrightside(point* p, point* p0, point* p1)
 {
     return (p1->x - p->x) * (p0->y - p->y) > (p0->x - p->x) * (p1->y - p->y);
 }
@@ -606,7 +620,7 @@ int delaunay_xytoi(delaunay* d, point* p, int id)
         for (i = 0; i < 3; ++i) {
             int i1 = (i + 1) % 3;
 
-            if (on_right_side(p, &d->points[t->vids[i]], &d->points[t->vids[i1]])) {
+            if (onrightside(p, &d->points[t->vids[i]], &d->points[t->vids[i1]])) {
                 id = d->neighbours[id].tids[(i + 2) % 3];
                 if (id < 0)
                     return id;
@@ -619,6 +633,25 @@ int delaunay_xytoi(delaunay* d, point* p, int id)
     return id;
 }
 
+static void delaunay_addflag(delaunay* d, int i)
+{
+    if (d->nflags == d->nflagsallocated) {
+        d->nflagsallocated += N_FLAGS_INC;
+        d->flagids = realloc(d->flagids, d->nflagsallocated * sizeof(int));
+    }
+    d->flagids[d->nflags] = i;
+    d->nflags++;
+}
+
+static void delaunay_resetflags(delaunay* d)
+{
+    int i;
+
+    for (i = 0; i < d->nflags; ++i)
+        d->flags[d->flagids[i]] = 0;
+    d->nflags = 0;
+}
+
 /* Finds all tricircles specified point belongs to.
  *
  * @param d Delaunay triangulation
@@ -630,7 +663,7 @@ int delaunay_xytoi(delaunay* d, point* p, int id)
  *
  * There is a standard search procedure involving search through triangle
  * neighbours (not through vertex neighbours). It must be a bit faster due to
- * the smaller number of triangle neighbours (3 per triangle) but can fail
+ * the smaller number of triangle neighbours (3 per triangle) but may fail
  * for a point outside convex hall.
  *
  * We may wish to modify this procedure in future: first check if the point
@@ -640,6 +673,15 @@ int delaunay_xytoi(delaunay* d, point* p, int id)
  */
 void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
 {
+    /*
+     * This flag was introduced as a hack to handle some degenerate cases. It 
+     * is set to 1 only if the triangle associated with the first circle is
+     * already known to contain the point. In this case the circle is assumed 
+     * to contain the point without a check. In my practice this turned
+     * useful in some cases when point p coincided with one of the vertices
+     * of a thin triangle. 
+     */
+    int contains = 0;
     int i;
 
     if (d->t_in == NULL) {
@@ -647,21 +689,43 @@ void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
         d->t_out = istack_create();
     }
 
+    /*
+     * if there are only a few data points, do linear search
+     */
+    if (d->ntriangles <= N_SEARCH_TURNON) {
+        istack_reset(d->t_out);
+
+        for (i = 0; i < d->ntriangles; ++i) {
+            if (circle_contains(&d->circles[i], p)) {
+                istack_push(d->t_out, i);
+            }
+        }
+
+        *n = d->t_out->n;
+        *out = d->t_out->v;
+
+        return;
+    }
+    /*
+     * otherwise, do a more complicated stuff
+     */
+
     /*
      * It is important to have a reasonable seed here. If the last search
      * was successful -- start with the last found tricircle, otherwhile (i) 
-     * try to find a triangle containing (x,y); if fails then (ii) check
+     * try to find a triangle containing p; if fails then (ii) check
      * tricircles from the last search; if fails then (iii) make linear
      * search through all tricircles 
      */
     if (d->first_id < 0 || !circle_contains(&d->circles[d->first_id], p)) {
         /*
-         * if any triangle contains (x,y) -- start with this triangle 
+         * if any triangle contains p -- start with this triangle 
          */
         d->first_id = delaunay_xytoi(d, p, d->first_id);
+        contains = (d->first_id >= 0);
 
         /*
-         * if no triangle contains (x,y), there still is a chance that it is
+         * if no triangle contains p, there still is a chance that it is
          * inside some of circumcircles 
          */
         if (d->first_id < 0) {
@@ -679,7 +743,7 @@ void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
             /*
              * if unsuccessful, search through all circles 
              */
-            if (tid < 0 || tid == nn) {
+            if (tid < 0 || i == nn) {
                 double nt = d->ntriangles;
 
                 for (tid = 0; tid < nt; ++tid) {
@@ -702,6 +766,7 @@ void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
 
     istack_push(d->t_in, d->first_id);
     d->flags[d->first_id] = 1;
+    delaunay_addflag(d, d->first_id);
 
     /*
      * main cycle 
@@ -710,7 +775,7 @@ void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
         int tid = istack_pop(d->t_in);
         triangle* t = &d->triangles[tid];
 
-        if (circle_contains(&d->circles[tid], p)) {
+        if (contains || circle_contains(&d->circles[tid], p)) {
             istack_push(d->t_out, tid);
             for (i = 0; i < 3; ++i) {
                 int vid = t->vids[i];
@@ -723,12 +788,15 @@ void delaunay_circles_find(delaunay* d, point* p, int* n, int** out)
                     if (d->flags[ntid] == 0) {
                         istack_push(d->t_in, ntid);
                         d->flags[ntid] = 1;
+                        delaunay_addflag(d, ntid);
                     }
                 }
             }
         }
+        contains = 0;
     }
 
     *n = d->t_out->n;
     *out = d->t_out->v;
+    delaunay_resetflags(d);
 }
