@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Grid_Terrain_Map.cpp 2484 2015-05-02 13:46:42Z reklov_w $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -92,7 +92,7 @@ CGrid_Terrain_Map::CGrid_Terrain_Map(void)
 		"This module allows one to create different terrain visualisations from an elevation dataset:\n\n"
 		"* Topography: a simple map with an analytical hillshading of the terrain\n\n"
 		"* Morphology: a map which visualizes the terrain by combining positive and "
-		"negative openess (Yokoyama et al. 2002) with terrain slope in a single map. "
+		"negative openness (Yokoyama et al. 2002) with terrain slope in a single map. "
 		"In contrast to conventional shading methods this has the advantage of being "
 		"independent from the direction of the light source.\n\n"
 		"References:\n"
