@@ -64,9 +64,15 @@
 
 //---------------------------------------------------------
 #include "MLB_Interface.h"
+
+#include "opencv2/core/version.hpp"
+
+#if CV_MAJOR_VERSION == 2
+
 #include <opencv/cxcore.h>
 #include <opencv/ml.h>
 
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -108,6 +114,22 @@ private:
 };
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define new_COpenCV_NNet	new COpenCV_NNet
+
+#else // CV_MAJOR_VERSION == 2
+
+#define new_COpenCV_NNet	MLB_INTERFACE_SKIP_MODULE
+
+#endif
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
