@@ -123,7 +123,7 @@ CSkeletonization::CSkeletonization(void)
 
 		CSG_String::Format(SG_T("%s|%s|"),
 			_TL("Less than"),
-			_TL("Greater than") 
+			_TL("Greater than")
 		),1
 	);
 
@@ -171,14 +171,14 @@ bool CSkeletonization::On_Execute(void)
 		switch( Initiation )
 		{
 		case 0: default:
-			if( pInput->asDouble(n) < Threshold )
+			if( !pInput->is_NoData(n) && pInput->asDouble(n) < Threshold )
 			{
 				pResult->Set_Value(n, 1);
 			}
 			break;
 
 		case 1:
-			if( pInput->asDouble(n) > Threshold )
+			if( !pInput->is_NoData(n) && pInput->asDouble(n) > Threshold )
 			{
 				pResult->Set_Value(n, 1);
 			}
@@ -189,17 +189,9 @@ bool CSkeletonization::On_Execute(void)
 	//-----------------------------------------------------
 	switch( Parameters("METHOD")->asInt() )
 	{
-	case 0:	default:
-		Standard_Execute();
-		break;
-
-	case 1:
-		Hilditch_Execute();
-		break;
-
-	case 2:
-		SK_Execute();
-		break;
+	default:	Standard_Execute();		break;
+	case  1:	Hilditch_Execute();		break;
+	case  2:	SK_Execute();			break;
 	}
 
 	//-------------------------------------------------
@@ -215,14 +207,14 @@ bool CSkeletonization::On_Execute(void)
 			switch( Initiation )
 			{
 			case 0: default:
-				if( pInput->asDouble(n) < Threshold )
+				if( !pInput->is_NoData(n) && pInput->asDouble(n) < Threshold )
 				{
 					pResult->Add_Value(n, 1);
 				}
 				break;
 
 			case 1:
-				if( pInput->asDouble(n) > Threshold )
+				if( !pInput->is_NoData(n) && pInput->asDouble(n) > Threshold )
 				{
 					pResult->Add_Value(n, 1);
 				}
@@ -301,7 +293,7 @@ int CSkeletonization::Vectorize(CSG_Shapes *pShapes)
 			if( pResult->asByte(x, y) )
 			{
 				n	= Get_Neighbours(x, y, pResult, z);
-				
+
 				if( n == 1 )
 				{
 					Lock_Set(x, y, SEGMENT_END);
@@ -707,7 +699,7 @@ int CSkeletonization::Hilditch_Step(CSG_Grid *pPrev, CSG_Grid *pNext, CSG_Grid *
 				}
 				else
 				{
-					pNext->Set_Value(x, y, true);
+					pNext->Set_Value(x, y, 1.0);
 				}
 			}
 		}
@@ -761,16 +753,18 @@ inline bool CSkeletonization::Hilditch_Check(CSG_Grid *pNC_Gaps, int x, int y, i
 //---------------------------------------------------------
 void CSkeletonization::SK_Execute(void)
 {
-	int		x, y, i, ix, iy, n,
-			Convergence, NB[8];
-
+	int		x, y, i, ix, iy, n, NB[8], Convergence;
 	double	z, iz;
 
-	CSG_Grid	*pInput;
-
 	//-----------------------------------------------------
+	CSG_Grid	*pInput		= Parameters("INPUT")->asGrid();
+
+	if( !pInput->Set_Index() )
+	{
+		Error_Set(_TL("index creation failed"));
+	}
+
 	Convergence	= Parameters("CONVERGENCE")->asInt();
-	pInput		= Parameters("INPUT")->asGrid();
 
 	pResult->Assign();
 
@@ -808,7 +802,7 @@ void CSkeletonization::SK_Execute(void)
 	// 2.) Find channels...
 
 	for(n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
-	{	
+	{
 		if( pInput->Get_Sorted(n, x, y) )	// Von oben nach unten...
 		{
 			z	= pInput->asDouble(x, y);
