@@ -101,6 +101,7 @@ CSG_String Get_Info(int i)
 #include "gdal_export.h"
 #include "gdal_export_geotiff.h"
 #include "gdal_import_netcdf.h"
+#include "gdal_import_wms.h"
 #include "gdal_catalogue.h"
 
 #include "ogr_import.h"
@@ -127,10 +128,12 @@ CSG_Module *		Create_Module(int i)
 
 	case  5:	return( new COGR_Export_KML );
 
-	case  6:	return( SG_Get_GDAL_Drivers().Get_Driver("netCDF") ? new CGDAL_Import_NetCDF : NULL );
+	case  6:	return( SG_Get_GDAL_Drivers().Get_Driver("netCDF") ? new CGDAL_Import_NetCDF : MLB_INTERFACE_SKIP_MODULE );
+
+	case  9:	return( new CGDAL_Import_WMS );
 
 	//-----------------------------------------------------
-	case  9:	return( NULL );
+	case 10:	return( NULL );
 	default:	return( MLB_INTERFACE_SKIP_MODULE );
 	}
 
