@@ -113,6 +113,12 @@ CSG_OGR_Drivers::~CSG_OGR_Drivers(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+CSG_String CSG_OGR_Drivers::Get_Version(void) const
+{
+	return( GDALVersionInfo("RELEASE_NAME") );
+}
+
 //---------------------------------------------------------
 int CSG_OGR_Drivers::Get_Count(void) const
 {
@@ -143,6 +149,30 @@ CSG_String CSG_OGR_Drivers::Get_Description(int Index) const
 	return( m_pDrivers->GetDriver(Index)->GetDescription() );
 }
 
+//---------------------------------------------------------
+CSG_String CSG_OGR_Drivers::Get_Extension(int Index) const
+{
+	return( Get_Driver(Index)->GetMetadataItem(GDAL_DMD_EXTENSION) );
+}
+
+//---------------------------------------------------------
+bool CSG_OGR_Drivers::is_Vector(int Index) const
+{
+	return( Get_Driver(Index) && CSLFetchBoolean(Get_Driver(Index)->GetMetadata(), GDAL_DCAP_VECTOR, false) );
+}
+
+//---------------------------------------------------------
+bool CSG_OGR_Drivers::Can_Read(int Index) const
+{
+	return( Get_Driver(Index) != NULL );
+}
+
+//---------------------------------------------------------
+bool CSG_OGR_Drivers::Can_Write(int Index) const
+{
+	return( Get_Driver(Index) && CSLFetchBoolean(Get_Driver(Index)->GetMetadata(), GDAL_DCAP_CREATE, false) );
+}
+
 #else
 //---------------------------------------------------------
 OGRSFDriver * CSG_OGR_Drivers::Get_Driver(int Index) const
@@ -195,7 +225,17 @@ CSG_String CSG_OGR_Drivers::Get_Description(int Index) const
 	return( s );
 }
 
-#endif
+//---------------------------------------------------------
+CSG_String CSG_OGR_Drivers::Get_Extension(int Index) const
+{
+	return( "" );
+}
+
+//---------------------------------------------------------
+bool CSG_OGR_Drivers::is_Vector(int Index) const
+{
+	return( true );
+}
 
 //---------------------------------------------------------
 bool CSG_OGR_Drivers::Can_Read(int Index) const
@@ -206,9 +246,11 @@ bool CSG_OGR_Drivers::Can_Read(int Index) const
 //---------------------------------------------------------
 bool CSG_OGR_Drivers::Can_Write(int Index) const
 {
-	return( Get_Driver(Index) != NULL );//&& Get_Driver(Index)->TestCapability(ODrCCreateDataSource) );
+	return( Get_Driver(Index) );
 }
 
+#endif // #ifndef USE_GDAL_V2
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -347,36 +389,36 @@ int CSG_OGR_Drivers::Get_Data_Type(TSG_Data_Type Type)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_OGR_DataSource::CSG_OGR_DataSource(void)
+CSG_OGR_DataSet::CSG_OGR_DataSet(void)
 {
-	m_pDataSource	= NULL;
+	m_pDataSet	= NULL;
 }
 
-CSG_OGR_DataSource::CSG_OGR_DataSource(const CSG_String &File)
+CSG_OGR_DataSet::CSG_OGR_DataSet(const CSG_String &File)
 {
-	m_pDataSource	= NULL;
+	m_pDataSet	= NULL;
 
 	Create(File);
 }
 
 //---------------------------------------------------------
-CSG_OGR_DataSource::~CSG_OGR_DataSource(void)
+CSG_OGR_DataSet::~CSG_OGR_DataSet(void)
 {
 	Destroy();
 }
 
 #ifdef USE_GDAL_V2
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::Create(const CSG_String &File)
+bool CSG_OGR_DataSet::Create(const CSG_String &File)
 {
 	Destroy();
 
-	m_pDataSource	= (GDALDataset *)GDALOpenEx(File, GDAL_OF_VECTOR, NULL, NULL, NULL);
+	m_pDataSet	= (GDALDataset *)GDALOpenEx(File, GDAL_OF_VECTOR, NULL, NULL, NULL);
 
-	return( m_pDataSource != NULL );
+	return( m_pDataSet != NULL );
 }
 
-bool CSG_OGR_DataSource::Create(const CSG_String &File, const CSG_String &DriverName)
+bool CSG_OGR_DataSet::Create(const CSG_String &File, const CSG_String &DriverName)
 {
 	GDALDriver	*pDriver;
 
@@ -384,37 +426,76 @@ bool CSG_OGR_DataSource::Create(const CSG_String &File, const CSG_String &Driver
 
 	if( (pDriver = gSG_OGR_Drivers.Get_Driver(DriverName)) != NULL )
 	{
-		m_pDataSource	= pDriver->Create(File, 0, 0, 0, GDT_Unknown, NULL);
+		m_pDataSet	= pDriver->Create(File, 0, 0, 0, GDT_Unknown, NULL);
 	}
 
-	return( m_pDataSource != NULL );
+	return( m_pDataSet != NULL );
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::Destroy(void)
+bool CSG_OGR_DataSet::Destroy(void)
 {
-	if( m_pDataSource )
+	if( m_pDataSet )
 	{
-		GDALClose(m_pDataSource);
+		GDALClose(m_pDataSet);
 
-		m_pDataSource	= NULL;
+		m_pDataSet	= NULL;
 	}
 
 	return( true );
 }
 
+//---------------------------------------------------------
+CSG_String CSG_OGR_DataSet::Get_DriverID(void)	const
+{
+	return( m_pDataSet && m_pDataSet->GetDriver() && m_pDataSet->GetDriver()->GetDescription() ? m_pDataSet->GetDriver()->GetDescription() : "" );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_OGR_DataSet::Get_Description(void)	const
+{
+	return( m_pDataSet ? m_pDataSet->GetDescription() : "" );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_OGR_DataSet::Get_Description(int i)	const
+{
+	CSG_String		Description;
+
+	OGRLayer	*pLayer	= Get_Layer(i);
+
+	if( pLayer != NULL )
+	{
+		char	**pMetaData	= pLayer->GetMetadata() + 0;
+
+		if( pMetaData )
+		{
+			while( *pMetaData )
+			{
+				CSG_String	s(*pMetaData);
+
+				Description	+= s + "\n";
+
+				pMetaData++;
+			}
+		}
+	}
+
+	return( Description );
+}
+
 #else
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::Create(const CSG_String &File)
+bool CSG_OGR_DataSet::Create(const CSG_String &File)
 {
 	Destroy();
 
-	m_pDataSource	= OGRSFDriverRegistrar::Open(File);
+	m_pDataSet	= OGRSFDriverRegistrar::Open(File);
 
-	return( m_pDataSource != NULL );
+	return( m_pDataSet != NULL );
 }
 
-bool CSG_OGR_DataSource::Create(const CSG_String &File, const CSG_String &DriverName)
+bool CSG_OGR_DataSet::Create(const CSG_String &File, const CSG_String &DriverName)
 {
 	OGRSFDriver	*pDriver;
 
@@ -422,25 +503,30 @@ bool CSG_OGR_DataSource::Create(const CSG_String &File, const CSG_String &Driver
 
 	if( (pDriver = gSG_OGR_Drivers.Get_Driver(DriverName)) != NULL )
 	{
-		m_pDataSource	= pDriver->CreateDataSource(File, NULL);
+		m_pDataSet	= pDriver->CreateDataSource(File, NULL);
 	}
 
-	return( m_pDataSource != NULL );
+	return( m_pDataSet != NULL );
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::Destroy(void)
+bool CSG_OGR_DataSet::Destroy(void)
 {
-	if( m_pDataSource )
+	if( m_pDataSet )
 	{
-		OGRDataSource::DestroyDataSource(m_pDataSource);
+		OGRDataSource::DestroyDataSource(m_pDataSet);
 
-		m_pDataSource	= NULL;
+		m_pDataSet	= NULL;
 	}
 
 	return( true );
 }
 
+//---------------------------------------------------------
+CSG_String CSG_OGR_DataSet::Get_DriverID   (void)	const	{	return( "" );	}
+CSG_String CSG_OGR_DataSet::Get_Description(void)	const	{	return( "" );	}
+CSG_String CSG_OGR_DataSet::Get_Description(int i)	const	{	return( "" );	}
+
 #endif
 
 
@@ -451,29 +537,29 @@ bool CSG_OGR_DataSource::Destroy(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int CSG_OGR_DataSource::Get_Count(void)
+int CSG_OGR_DataSet::Get_Count(void)	const
 {
-	if( m_pDataSource )
+	if( m_pDataSet )
 	{
-		return( m_pDataSource->GetLayerCount() );
+		return( m_pDataSet->GetLayerCount() );
 	}
 
 	return( 0 );
 }
 
 //---------------------------------------------------------
-OGRLayer * CSG_OGR_DataSource::Get_Layer(int iLayer)
+OGRLayer * CSG_OGR_DataSet::Get_Layer(int iLayer)	const
 {
-	if( m_pDataSource && iLayer >= 0 && iLayer < m_pDataSource->GetLayerCount() )
+	if( m_pDataSet && iLayer >= 0 && iLayer < m_pDataSet->GetLayerCount() )
 	{
-		return( m_pDataSource->GetLayer(iLayer) );
+		return( m_pDataSet->GetLayer(iLayer) );
 	}
 
 	return( NULL );
 }
 
 //---------------------------------------------------------
-TSG_Shape_Type CSG_OGR_DataSource::Get_Type(int iLayer)
+TSG_Shape_Type CSG_OGR_DataSet::Get_Type(int iLayer)	const
 {
 	if( Get_Layer(iLayer) )
 	{
@@ -484,7 +570,7 @@ TSG_Shape_Type CSG_OGR_DataSource::Get_Type(int iLayer)
 }
 
 //---------------------------------------------------------
-TSG_Vertex_Type CSG_OGR_DataSource::Get_Coordinate_Type(int iLayer)
+TSG_Vertex_Type CSG_OGR_DataSet::Get_Coordinate_Type(int iLayer)	const
 {
 	if( Get_Layer(iLayer) )
 	{
@@ -495,7 +581,7 @@ TSG_Vertex_Type CSG_OGR_DataSource::Get_Coordinate_Type(int iLayer)
 }
 
 //---------------------------------------------------------
-CSG_Projection CSG_OGR_DataSource::Get_Projection(int iLayer)
+CSG_Projection CSG_OGR_DataSet::Get_Projection(int iLayer)	const
 {
 	CSG_Projection	Projection;
 
@@ -531,7 +617,7 @@ CSG_Projection CSG_OGR_DataSource::Get_Projection(int iLayer)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Shapes * CSG_OGR_DataSource::Read(int iLayer, int iGeomTypeChoice)
+CSG_Shapes * CSG_OGR_DataSet::Read(int iLayer, int iGeomTypeChoice)
 {
 	//-----------------------------------------------------
 	OGRLayer	*pLayer	= Get_Layer(iLayer);
@@ -607,7 +693,7 @@ CSG_Shapes * CSG_OGR_DataSource::Read(int iLayer, int iGeomTypeChoice)
 }
 
 //---------------------------------------------------------
-int CSG_OGR_DataSource::_Get_GeomType_Choice(int iGeomTypeChoice)
+int CSG_OGR_DataSet::_Get_GeomType_Choice(int iGeomTypeChoice)
 {
 	switch( iGeomTypeChoice )
 	{
@@ -631,7 +717,7 @@ int CSG_OGR_DataSource::_Get_GeomType_Choice(int iGeomTypeChoice)
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::_Read_Geometry(CSG_Shape *pShape, OGRGeometry *pGeometry)
+bool CSG_OGR_DataSet::_Read_Geometry(CSG_Shape *pShape, OGRGeometry *pGeometry)
 {
 	if( pShape && pGeometry )
 	{
@@ -683,7 +769,7 @@ bool CSG_OGR_DataSource::_Read_Geometry(CSG_Shape *pShape, OGRGeometry *pGeometr
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::_Read_Line(CSG_Shape *pShape, OGRLineString *pLine)
+bool CSG_OGR_DataSet::_Read_Line(CSG_Shape *pShape, OGRLineString *pLine)
 {
 	if( pShape && pLine && pLine->getNumPoints() > 0 )
 	{
@@ -703,7 +789,7 @@ bool CSG_OGR_DataSource::_Read_Line(CSG_Shape *pShape, OGRLineString *pLine)
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::_Read_Polygon(CSG_Shape *pShape, OGRPolygon *pPolygon)
+bool CSG_OGR_DataSet::_Read_Polygon(CSG_Shape *pShape, OGRPolygon *pPolygon)
 {
 	if( pShape && pPolygon )
 	{
@@ -728,9 +814,9 @@ bool CSG_OGR_DataSource::_Read_Polygon(CSG_Shape *pShape, OGRPolygon *pPolygon)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::Write(CSG_Shapes *pShapes, const CSG_String &DriverName)
+bool CSG_OGR_DataSet::Write(CSG_Shapes *pShapes)
 {
-	if( !m_pDataSource || !pShapes || !pShapes->is_Valid() )
+	if( !m_pDataSet || !pShapes || !pShapes->is_Valid() )
 	{
 		return( false );
 	}
@@ -745,7 +831,7 @@ bool CSG_OGR_DataSource::Write(CSG_Shapes *pShapes, const CSG_String &DriverName
 	//	pSRS	->importFromProj4(pShapes->Get_Projection().Get_Proj4());
 	}
 
-	OGRLayer	*pLayer	= m_pDataSource->CreateLayer(CSG_String(pShapes->Get_Name()), pSRS,
+	OGRLayer	*pLayer	= m_pDataSet->CreateLayer(CSG_String(pShapes->Get_Name()), pSRS,
 		(OGRwkbGeometryType)gSG_OGR_Drivers.Get_Shape_Type(pShapes->Get_Type(), pShapes->Get_Vertex_Type() != SG_VERTEX_TYPE_XY)
 	);
 
@@ -755,7 +841,8 @@ bool CSG_OGR_DataSource::Write(CSG_Shapes *pShapes, const CSG_String &DriverName
 	}
 
 	//-------------------------------------------------
-	if( SG_STR_CMP(DriverName, "DXF") )
+#ifdef USE_GDAL_V2
+	if( SG_STR_CMP(m_pDataSet->GetDriver()->GetDescription(), "DXF") )
 	{
 		// the dxf driver does not support arbitrary field creation and returns OGRERR_FAILURE;
 		// it seems like there is no method in OGR to check whether a driver supports field creation or not;
@@ -773,6 +860,7 @@ bool CSG_OGR_DataSource::Write(CSG_Shapes *pShapes, const CSG_String &DriverName
 			}
 		}
 	}
+#endif
 
 	//-----------------------------------------------------
 	for(int iShape=0; iShape<pShapes->Get_Count() && SG_UI_Process_Set_Progress(iShape, pShapes->Get_Count()); iShape++)
@@ -819,7 +907,7 @@ bool CSG_OGR_DataSource::Write(CSG_Shapes *pShapes, const CSG_String &DriverName
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::_Write_Geometry(CSG_Shape *pShape, OGRFeature *pFeature, bool bZ)
+bool CSG_OGR_DataSet::_Write_Geometry(CSG_Shape *pShape, OGRFeature *pFeature, bool bZ)
 {
 	if( !pShape || !pFeature )
 	{
@@ -910,7 +998,7 @@ bool CSG_OGR_DataSource::_Write_Geometry(CSG_Shape *pShape, OGRFeature *pFeature
 }
 
 //---------------------------------------------------------
-bool CSG_OGR_DataSource::_Write_Line(CSG_Shape *pShape, OGRLineString *pLine, int iPart, bool bZ)
+bool CSG_OGR_DataSet::_Write_Line(CSG_Shape *pShape, OGRLineString *pLine, int iPart, bool bZ)
 {
 	if( pLine && pShape && iPart >= 0 && iPart < pShape->Get_Part_Count() )
 	{
