@@ -234,7 +234,7 @@ CTable_Text_Import::CTable_Text_Import(void)
 	//-----------------------------------------------------
 	Set_Name		(_TL("Import Text Table"));
 
-	Set_Author		(SG_T("O. Conrad (c) 2008"));
+	Set_Author		("O. Conrad (c) 2008");
 
 	Set_Description	(_TW(
 		""
@@ -256,7 +256,7 @@ CTable_Text_Import::CTable_Text_Import(void)
 	pNode	= Parameters.Add_Choice(
 		NULL	, "SEPARATOR"	, _TL("Separator"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|%s|"),
+		CSG_String::Format("%s|%s|%s|%s|%s|",
 			_TL("tabulator"),
 			SG_T(";"),
 			SG_T(","),
@@ -274,7 +274,7 @@ CTable_Text_Import::CTable_Text_Import(void)
 	Parameters.Add_FilePath(
 		NULL	, "FILENAME"	, _TL("File"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|%s|%s"),
+		CSG_String::Format("%s|%s|%s|%s|%s|%s",
 			_TL("Text Files (*.txt)")	, SG_T("*.txt"),
 			_TL("CSV Files (*.csv)")	, SG_T("*.csv"),
 			_TL("All Files")			, SG_T("*.*")
@@ -282,39 +282,43 @@ CTable_Text_Import::CTable_Text_Import(void)
 	);
 }
 
+//---------------------------------------------------------
+int CTable_Text_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( !SG_STR_CMP(pParameter->Get_Identifier(), "SEPARATOR") )
+	{
+		pParameters->Set_Enabled("SEP_OTHER", pParameter->asInt() >= 4);
+	}
+
+	return( CSG_Module::On_Parameters_Enable(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 bool CTable_Text_Import::On_Execute(void)
 {
-	bool		bHeader;
-	CSG_String	Separator;
-	CSG_Table	*pTable;
-
 	//-----------------------------------------------------
-	pTable	= Parameters("TABLE")		->asTable();
-	bHeader	= Parameters("HEADLINE")	->asBool();
+	CSG_Table	*pTable	= Parameters("TABLE")->asTable();
+
+	SG_Char	Separator;
 
 	switch( Parameters("SEPARATOR")->asInt() )
 	{
-	case 0:		Separator	= "\t";	break;
-	case 1:		Separator	=  ";";	break;
-	case 2:		Separator	=  ",";	break;
-	case 3:		Separator	=  " ";	break;
-	default:	Separator	= Parameters("SEP_OTHER")->asString();	break;
+	case  0:	Separator	= '\t';	break;
+	case  1:	Separator	=  ';';	break;
+	case  2:	Separator	=  ',';	break;
+	case  3:	Separator	=  ' ';	break;
+	default:	Separator	= *Parameters("SEP_OTHER")->asString();	break;
 	}
 
 	//-----------------------------------------------------
-	if( !pTable->Create(Parameters("FILENAME")->asString(), bHeader ? TABLE_FILETYPE_Text : TABLE_FILETYPE_Text_NoHeadLine, Separator) )
+	if( !pTable->Create(Parameters("FILENAME")->asString(), Parameters("HEADLINE")->asBool() ? TABLE_FILETYPE_Text : TABLE_FILETYPE_Text_NoHeadLine, Separator) )
 	{
-		Message_Add(_TL("table could not be opened."));
+		Error_Set(_TL("table could not be opened."));
+
+		return( false );
 	}
 
-	//-----------------------------------------------------
-	else
-	{
-		return( true );
-	}
-
-	return( false );
+	return( true );
 }
 
 
@@ -327,9 +331,12 @@ bool CTable_Text_Import::On_Execute(void)
 //---------------------------------------------------------
 CTable_Text_Import_Numbers::CTable_Text_Import_Numbers(void)
 {
+	CSG_Parameter	*pNode;
+
+	//-----------------------------------------------------
 	Set_Name		(_TL("Import Text Table with Numbers only"));
 
-	Set_Author		(SG_T("O. Conrad (c) 2008"));
+	Set_Author		("O. Conrad (c) 2008");
 
 	Set_Description	(_TW(
 		""
@@ -343,24 +350,31 @@ CTable_Text_Import_Numbers::CTable_Text_Import_Numbers(void)
 	);
 
 	Parameters.Add_Value(
-		NULL	, "HEADLINE"	, _TL("File contains headline"),
+		NULL	, "SKIP"		, _TL("Skip Lines"),
 		_TL(""),
-		PARAMETER_TYPE_Bool		, false
+		PARAMETER_TYPE_Int, 0, 0, true
 	);
 
-	Parameters.Add_Choice(
+	Parameters.Add_Value(
+		NULL	, "HEADLINE"	, _TL("Headline"),
+		_TL(""),
+		PARAMETER_TYPE_Bool, false
+	);
+
+	pNode	= Parameters.Add_Choice(
 		NULL	, "SEPARATOR"	, _TL("Separator"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|"),
+		CSG_String::Format("%s|%s|%s|%s|%s|",
 			_TL("tabulator"),
-			_TL(";"),
-			_TL(","),
+			SG_T(";"),
+			SG_T(","),
+			_TL("space"),
 			_TL("other")
 		), 0
 	);
 
 	Parameters.Add_String(
-		NULL	, "SEP_OTHER"	, _TL("Separator (other)"),
+		pNode	, "SEP_OTHER"	, _TL("other"),
 		_TL(""),
 		SG_T("*")
 	);
@@ -368,7 +382,7 @@ CTable_Text_Import_Numbers::CTable_Text_Import_Numbers(void)
 	Parameters.Add_FilePath(
 		NULL	, "FILENAME"	, _TL("File"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|%s|%s"),
+		CSG_String::Format("%s|%s|%s|%s|%s|%s",
 			_TL("Text Files (*.txt)")	, SG_T("*.txt"),
 			_TL("CSV Files (*.csv)")	, SG_T("*.csv"),
 			_TL("All Files")			, SG_T("*.*")
@@ -376,92 +390,130 @@ CTable_Text_Import_Numbers::CTable_Text_Import_Numbers(void)
 	);
 }
 
+//---------------------------------------------------------
+int CTable_Text_Import_Numbers::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( !SG_STR_CMP(pParameter->Get_Identifier(), "SEPARATOR") )
+	{
+		pParameters->Set_Enabled("SEP_OTHER", pParameter->asInt() >= 4);
+	}
+
+	return( CSG_Module::On_Parameters_Enable(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 bool CTable_Text_Import_Numbers::On_Execute(void)
 {
-	bool		bHeader;
-	double		Value;
-	CSG_String	sLine, sHead, Separator;
+	CSG_String	sHead, sLine, Separator;
 	CSG_File	Stream;
-	CSG_Table	*pTable;
-
-	//-----------------------------------------------------
-	pTable	= Parameters("TABLE")		->asTable();
-	bHeader	= Parameters("HEADLINE")	->asBool();
-
-	switch( Parameters("SEPARATOR")->asInt() )
-	{
-	case 0:		Separator	= "\t";	break;
-	case 1:		Separator	=  ";";	break;
-	case 2:		Separator	=  ",";	break;
-	default:	Separator	= Parameters("SEP_OTHER")->asString();	break;
-	}
 
 	//-----------------------------------------------------
 	if( !Stream.Open(Parameters("FILENAME")->asString(), SG_FILE_R, false) )
 	{
-		Message_Add(_TL("file could not be opened"));
+		Error_Set(_TL("file could not be opened"));
+
+		return( false );
 	}
 
+	if( Parameters("SKIP")->asInt() > 0 )
+	{
+		int	i	= Parameters("SKIP")->asInt();
+		
+		while( i > 0 && Stream.Read_Line(sLine) )	{ i--; }
+	}
+
+	if( !Stream.Read_Line(sHead) || sHead.Length() == 0 )
+	{
+		Error_Set(_TL("empty or corrupted file"));
+
+		return( false );
+	}
+
+	if( !Parameters("HEADLINE")->asBool() )
+	{
+		sLine	= sHead;
+	}
 	else if( !Stream.Read_Line(sLine) || sLine.Length() == 0 )
 	{
-		Message_Add(_TL("empty or corrupted file"));
-	}
+		Error_Set(_TL("empty or corrupted file"));
 
-	else if( bHeader && (!Stream.Read_Line(sLine) || sLine.Length() == 0) )
-	{
-		Message_Add(_TL("empty or corrupted file"));
+		return( false );
 	}
 
 	//-----------------------------------------------------
-	else
+	switch( Parameters("SEPARATOR")->asInt() )
 	{
-		pTable->Destroy();
-		pTable->Set_Name(SG_File_Get_Name(Parameters("FILENAME")->asString(), false));
-
-		sLine.Replace(Separator, SG_T("\t"));
-		sHead	= sLine;
-
-		do
-		{
-			sHead.Trim();
-
-			if( sHead.asDouble(Value) )
-			{
-				pTable->Add_Field(CSG_String::Format(SG_T("%d"), 1 + pTable->Get_Field_Count()), SG_DATATYPE_Double);
-			}
-
-			sHead	= sHead.AfterFirst('\t');
-		}
-		while( sHead.Length() > 0 );
-
-		//-------------------------------------------------
-		if( pTable->Get_Field_Count() > 0 )
-		{
-			int		fLength	= Stream.Length();
-
-			do
-			{
-				sLine.Replace(Separator, SG_T("\t"));
-
-				CSG_Table_Record	*pRecord	= pTable->Add_Record();
-
-				for(int i=0; i<pTable->Get_Field_Count(); i++)
-				{
-					sLine.Trim();
-
-					pRecord->Set_Value(i, sLine.asDouble());
-
-					sLine	= sLine.AfterFirst('\t');
-				}
-			}
-			while( Stream.Read_Line(sLine) && sLine.Length() > 0 && Set_Progress(Stream.Tell(), fLength) );
-		}
-
-		return( true );
+	case  0:	Separator	= "\t";	break;
+	case  1:	Separator	=  ";";	break;
+	case  2:	Separator	=  ",";	break;
+	case  3:	Separator	=  " ";	break;
+	default:	Separator	= Parameters("SEP_OTHER")->asString();	break;
 	}
 
-	return( false );
+	//-----------------------------------------------------
+	CSG_Table	*pTable	= Parameters("TABLE")->asTable();
+
+	pTable->Destroy();
+	pTable->Set_Name(SG_File_Get_Name(Parameters("FILENAME")->asString(), false));
+
+	sHead.Trim(true);
+	sHead.Replace(Separator, "\t");
+
+	while( sHead.Length() > 0 )
+	{
+		sHead.Trim();
+
+		if( Parameters("HEADLINE")->asBool() )
+		{
+			pTable->Add_Field(sHead.BeforeFirst('\t'), SG_DATATYPE_Double);
+		}
+		else
+		{
+			pTable->Add_Field(CSG_String::Format("FIELD%02d", 1 + pTable->Get_Field_Count()), SG_DATATYPE_Double);
+		}
+
+		sHead	= sHead.AfterFirst('\t');
+	}
+
+	if( pTable->Get_Field_Count() <= 0 )
+	{
+		Error_Set(_TL("empty or corrupted file"));
+
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	int		fLength	= Stream.Length();
+
+	bool	bOkay	= true;
+
+	do
+	{
+		sLine.Replace(Separator, "\t");
+
+		CSG_Table_Record	*pRecord	= pTable->Add_Record();
+
+		for(int i=0; bOkay && i<pTable->Get_Field_Count(); i++)
+		{
+			double	Value;
+
+			sLine.Trim();
+
+			if( (bOkay = sLine.asDouble(Value)) == true )
+			{
+				pRecord->Set_Value(i, Value);
+
+				sLine	= sLine.AfterFirst('\t');
+			}
+			else
+			{
+				pTable->Del_Record(pTable->Get_Count() - 1);
+			}
+		}
+	}
+	while( bOkay && Stream.Read_Line(sLine) && Set_Progress(Stream.Tell(), fLength) );
+
+	return( pTable->Get_Count() > 0 );
 }
 
 
