@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: pc_get_subset_spcvf.cpp 2841 2016-03-05 11:25:04Z reklov_w $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -424,19 +424,29 @@ bool CPointCloud_Get_Subset_SPCVF_Base::Get_Subset(bool bCopyAttr)
 
 					if( bCopyAttr )
 					{
-						for(int iField=0; iField<pPC->Get_Attribute_Count(); iField++)
+						for (int j=0; j<pPC->Get_Attribute_Count(); j++)
 						{
-							pPC_out->Set_Attribute(iField, pPC->Get_Attribute(iPoint, iField));
+							switch (pPC->Get_Attribute_Type(j))
+							{
+							default:					pPC_out->Set_Attribute(j, pPC->Get_Attribute(iPoint, j));		break;
+							case SG_DATATYPE_Date:
+							case SG_DATATYPE_String:	CSG_String sAttr; pPC->Get_Attribute(iPoint, j, sAttr); pPC_out->Set_Attribute(j, sAttr);		break;
+							}
 						}
 					}
 					else
 					{
-						for(int iField=0; iField<(int)m_vAttrMapper.size(); iField++)
+						for(int j=0; j<(int)m_vAttrMapper.size(); j++)
 						{
-							if( iField >= pPC->Get_Attribute_Count() )
+							if( j >= pPC->Get_Attribute_Count() )
 								continue;
 
-							pPC_out->Set_Attribute(iField, pPC->Get_Attribute(iPoint, m_vAttrMapper.at(iField)));
+							switch (pPC->Get_Attribute_Type(m_vAttrMapper.at(j)))
+							{
+							default:					pPC_out->Set_Attribute(j, pPC->Get_Attribute(iPoint, m_vAttrMapper.at(j)));		break;
+							case SG_DATATYPE_Date:
+							case SG_DATATYPE_String:	CSG_String sAttr; pPC->Get_Attribute(iPoint, m_vAttrMapper.at(j), sAttr); pPC_out->Set_Attribute(j, sAttr);		break;
+							}
 						}
 					}
 
