@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: pc_cluster_analysis.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -85,18 +85,12 @@ CPC_Cluster_Analysis::CPC_Cluster_Analysis(void)
 	Set_Author		(SG_T("Volker Wichmann (c) 2010, LASERDATA GmbH"));
 
 	Set_Description	(_TW(		
-		"Cluster Analysis for Point Clouds.\n\n"
-		"Module usage is different between SAGA GUI and SAGA CMD: With "
-		"SAGA GUI you will get prompted to choose the attributes to use "
-		"once you execute the module. With SAGA CMD you have to provide "
-		"a string with the -ATTR_FIELDS parameter containing the field "
-		"numbers of the attributes to use (separated by semicolon). Field "
-		"numbers start with 1, e.g. -ATTR_FIELDS=\"4;5;7\".\n\n" 
+		"Cluster analysis for point clouds.\n\n"
 		
 		"References:\n\n"
 
-		"This module is a port of the 'Cluster Analysis for Grids' "
-		"module from the 'Imagery - Classification' module library, "
+		"This tool is a port of the 'Cluster Analysis for Grids' "
+		"module from the 'Imagery - Classification' tool library, "
 		"Copyright (C) 2003 by Olaf Conrad.\n\n"
 
 		"Iterative Minimum Distance:\n"
@@ -114,16 +108,21 @@ CPC_Cluster_Analysis::CPC_Cluster_Analysis(void)
 	//-----------------------------------------------------
 	// 2. Datasets...
 
-	Parameters.Add_PointCloud(
+	CSG_Parameter *pNode = Parameters.Add_PointCloud(
 		NULL	, "PC_IN"		,_TL("Point Cloud"),
 		_TL("Input"),
 		PARAMETER_INPUT
 	);
 
+	Parameters.Add_Table_Fields(
+		pNode	, "FIELDS"		, _TL("Attributes"),
+		_TL("The attribute fields to cluster")
+	);
+
 	Parameters.Add_PointCloud(
 		NULL	, "PC_OUT"		,_TL("Result"),
 		_TL("Output"),
-		PARAMETER_OUTPUT
+		PARAMETER_OUTPUT_OPTIONAL
 	);
 
 	Parameters.Add_Table(
@@ -157,23 +156,6 @@ CPC_Cluster_Analysis::CPC_Cluster_Analysis(void)
 		_TL("Automatically normalise attributes by standard deviation before clustering."),
 		PARAMETER_TYPE_Bool, true
 	);
-
-	if (!SG_UI_Get_Window_Main())
-	{
-		Parameters.Add_String(
-            NULL	, "ATTR_FIELDS"    , _TL("Attribute Fields"),
-            _TL("The numbers (starting from 1) of the fields to use for clustering, separated by semicolon, e.g. \"4;5;7\""),
-            SG_T("")
-        );
-	}
-	else
-	{
-		Parameters.Add_Value(
-			NULL	, "UPDATEVIEW"	, _TL("Update View"),
-			_TL("Update cluster view while clustering."),
-			PARAMETER_TYPE_Bool, true
-		);
-	}
 }
 
 
@@ -186,249 +168,175 @@ CPC_Cluster_Analysis::CPC_Cluster_Analysis(void)
 //---------------------------------------------------------
 bool CPC_Cluster_Analysis::On_Execute(void)
 {
-	int						i, j, nCluster, cnt;
-	long					nElements;
-	double					SP;
-	CSG_Parameters			Parms;
+	int				nCluster;
+	long			nElements;
+	double			SP;
 
 	//-----------------------------------------------------
 	nCluster	= Parameters("NCLUSTER")->asInt();
-	pInput		= Parameters("PC_IN")	->asPointCloud();
-	pResult		= Parameters("PC_OUT")	->asPointCloud();
-	pResult		->Create(pInput);
-	pResult		->Set_Name(CSG_String::Format(SG_T("%s_cluster"), pInput->Get_Name()));
-	pResult		->Add_Field(SG_T("CLUSTER"), SG_DATATYPE_Int);
-	DataObject_Update(pResult);
-	pResult		->Set_NoData_Value(- 1.0);
-	clustField	= pResult->Get_Field_Count()-1;
+	pPC_in		= Parameters("PC_IN")	->asPointCloud();
+	pPC_out		= Parameters("PC_OUT")	->asPointCloud();
+
+	//-------------------------------------------------
+	m_Features	= (int *)Parameters("FIELDS")->asPointer();
+	m_nFeatures	=        Parameters("FIELDS")->asInt    ();
+
+	if( !m_Features || m_nFeatures <= 0 )
+	{
+		Error_Set(_TL("no features in selection"));
+
+		return( false );
+	}
 
-	vFields.resize(pInput->Get_Field_Count());
 
 	//-----------------------------------------------------
-	if( SG_UI_Get_Window_Main() )	// GUI
-    {
-		CSG_Parameters			Parms;
-		CSG_String				fName, fID;
-
-		Parms.Set_Name(_TL("Choose the attributes to use for clustering:"));
-
-		for( int iField=0; iField<pInput->Get_Field_Count(); iField++ )
-		{
-			fName.Printf(SG_T("%s"), pInput->Get_Field_Name(iField));
-			fID.Printf(SG_T("FIELD_%03d"), iField);
-			Parms.Add_Value(NULL, fID, fName, _TL(""), PARAMETER_TYPE_Bool, false);
-		}
-
-		if( Dlg_Parameters(&Parms, _TL("")) )
-		{
-			for( int iField=0; iField<pInput->Get_Field_Count(); iField++ )
-			{
-				fID.Printf(SG_T("FIELD_%03d"), iField);
-
-				if( Parms.Get_Parameter(fID)->asBool() )
-					vFields.at(iField) = true;
-			}
-		}
-		else
-			return( false );
-	}
-	else		// CMD LINE
+	if (!pPC_out || pPC_out == pPC_in)
 	{
-		CSG_String		attrFields;
-		CSG_String		token;
-		int				field;
-
-		Parameters.Add_Value(
-			NULL	, "UPDATEVIEW"	, _TL("Update View"),
-			_TL("Update cluster view while clustering."),
-			PARAMETER_TYPE_Bool, false
-		);
-
-		attrFields		= Parameters("ATTR_FIELDS")->asString();
-
-		CSG_String_Tokenizer   tkz_fields(attrFields, ";", SG_TOKEN_STRTOK);
-
-		while( tkz_fields.Has_More_Tokens() )
-		{
-			token	= tkz_fields.Get_Next_Token();
-
-			if( token.Length() == 0 )
-				break;
-
-			if( !token.asInt(field) )
-			{
-				SG_UI_Msg_Add_Error(_TL("Error parsing attribute fields: can't convert to number"));
-				return( false );
-			}
-
-			field	-= 1;
-
-			if( field < 0 || field > (int)vFields.size() - 1 )
-			{
-				SG_UI_Msg_Add_Error(_TL("Error parsing attribute fields: field index out of range"));
-				return( false );
-			}
-			else
-				vFields.at(field)	= true;
-		}
+		pPC_out = &PC_out;
 	}
 
+	pPC_out->Create(pPC_in);
+
+	pPC_out->Add_Field(SG_T("CLUSTER"), SG_DATATYPE_Int);
+	clustField	= pPC_out->Get_Field_Count() - 1;
+
+	pPC_out->Set_NoData_Value(-1.0);
+	
 
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("Initializing ..."));
 
-	nFields		= 0;
+	for( int i=0; i<m_nFeatures; i++ )
+		vValues.push_back( std::vector<double>() );
 
-	for( i=0; i<(int)vFields.size(); i++ )
+	for( int i=0; i<pPC_in->Get_Record_Count() && SG_UI_Process_Set_Progress(i, pPC_in->Get_Record_Count()); i++ )
 	{
-		if( vFields.at(i) )
-			nFields++;
-	}
+		pPC_out->Add_Point(pPC_in->Get_X(i), pPC_in->Get_Y(i), pPC_in->Get_Z(i));
 
-	if( nFields > 0 )
-	{
-		for( i=0; i<nFields; i++ )
-			vValues.push_back( std::vector<double>() );
-
-		for( i=0; i<pInput->Get_Record_Count() && SG_UI_Process_Set_Progress(i, pInput->Get_Record_Count()); i++ )
+		for (int j=0; j<pPC_in->Get_Attribute_Count(); j++)
 		{
-			pResult->Add_Point(pInput->Get_X(i), pInput->Get_Y(i), pInput->Get_Z(i));
-			
-			cnt		= 0;
-
-			for( j=0; j<pInput->Get_Field_Count(); j++ )
+			switch (pPC_in->Get_Attribute_Type(j))
 			{
-				if( vFields.at(j) )
-				{
-					if( Parameters("NORMALISE")->asBool() )
-						vValues.at(cnt).push_back( (pInput->Get_Value(i, j) - pInput->Get_Mean(j)) / pInput->Get_StdDev(j) );
-					else
-						vValues.at(cnt).push_back(pInput->Get_Value(i, j));
-
-					cnt++;
-				}
-
-				if( j > 2 )
-					pResult->Set_Value(j, pInput->Get_Value(i, j));
+			default:					pPC_out->Set_Attribute(i, j, pPC_in->Get_Attribute(i, j));		break;
+			case SG_DATATYPE_Date:
+			case SG_DATATYPE_String:	CSG_String sAttr; pPC_in->Get_Attribute(i, j, sAttr); pPC_out->Set_Attribute(i, j, sAttr);		break;
 			}
 		}
+
+		pPC_out->Set_NoData(i, clustField);
 		
-		pResult->Set_NoData(clustField);
+		bool bNoData = false;
 
-		if( Parameters("UPDATEVIEW")->asBool() )
+		for( int j=0; j<m_nFeatures; j++)
 		{
-			if( DataObject_Get_Parameters(pResult, Parms) && Parms("COLORS_TYPE") && Parms("METRIC_ATTRIB") && Parms("METRIC_COLORS") && Parms("METRIC_ZRANGE") )
+			if( pPC_in->is_NoData(i, m_Features[j]) )
 			{
-				Parms("COLORS_TYPE")					->Set_Value(2);			// graduated color
-				Parms("METRIC_COLORS")->asColors()		->Set_Count(nCluster);
-				Parms("METRIC_ATTRIB")					->Set_Value(clustField);
-				Parms("METRIC_ZRANGE")->asRange()		->Set_Range(0, nCluster);
-			}
-			DataObject_Set_Parameters(pResult, Parms);
-			DataObject_Update(pResult, SG_UI_DATAOBJECT_SHOW_LAST_MAP);
-		}
-
-
-		nMembers	= (int     *)SG_Malloc(nCluster * sizeof(int));
-		Variances	= (double  *)SG_Malloc(nCluster * sizeof(double));
-		Centroids	= (double **)SG_Malloc(nCluster * sizeof(double *));
-
-		for( i=0; i<nCluster; i++ )
-		{
-			Centroids[i]	= (double  *)SG_Malloc(nFields * sizeof(double));
-		}
-
-		//-------------------------------------------------
-		nElements	= pInput->Get_Point_Count();
-
-		switch( Parameters("METHOD")->asInt() )
-		{
-		case 0:
-			SP	= MinimumDistance	(nElements, nCluster);
-			break;
-
-		case 1:
-			SP	= HillClimbing		(nElements, nCluster);
-			break;
-
-		case 2:
-			SP	= MinimumDistance	(nElements, nCluster);
-
-			nElements	= pInput->Get_Point_Count();	// may have been diminished because of no data values...
-
-			SP	= HillClimbing		(nElements, nCluster);
-			break;
-		}
-
-		//-------------------------------------------------
-		if( Parameters("NORMALISE")->asBool() )
-		{
-			int		iv = 0;
-
-			for( i=0; i<(int)vFields.size(); i++ )
-			{
-				if( vFields.at(i) )
-				{
-					for( j=0; j<nCluster; j++ )
-					{
-						Centroids[j][iv]	= sqrt(pInput->Get_Variance(i)) * Centroids[j][iv] + pInput->Get_Mean(i);
-					}
-
-					iv++;
-				}
+				bNoData = true;
+				break;
 			}
 		}
 
-		Write_Result(Parameters("STATISTICS")->asTable(), nElements, nCluster, SP);
-
-		//-------------------------------------------------
-		if( DataObject_Get_Parameters(pResult, Parms) && Parms("COLORS_TYPE") && Parms("LUT") && Parms("LUT_ATTRIB") )
+		if( !bNoData )
 		{
-			CSG_Table_Record	*pClass;
-			CSG_Table			*pLUT	= Parms("LUT")->asTable();
-
-			for( i=0; i<nCluster; i++ )
+			for( int j=0; j<m_nFeatures; j++ )
 			{
-				if( (pClass = pLUT->Get_Record(i)) == NULL )
-				{
-					pClass	= pLUT->Add_Record();
-					pClass->Set_Value(0, SG_GET_RGB(rand() * 255.0 / RAND_MAX, rand() * 255.0 / RAND_MAX, rand() * 255.0 / RAND_MAX));
-				}
-
-				pClass->Set_Value(1, CSG_String::Format(SG_T("%s %d"), _TL("Class"), i));
-				pClass->Set_Value(2, CSG_String::Format(SG_T("%s %d"), _TL("Class"), i));
-				pClass->Set_Value(3, i);
-				pClass->Set_Value(4, i);
+				if( Parameters("NORMALISE")->asBool() )
+					vValues.at(j).push_back( (pPC_in->Get_Value(i, m_Features[j]) - pPC_in->Get_Mean(m_Features[j])) / pPC_in->Get_StdDev(m_Features[j]) );
+				else
+					vValues.at(j).push_back(pPC_in->Get_Value(i, m_Features[j]));
 			}
-
-			while( pLUT->Get_Record_Count() > nCluster )
-			{
-				pLUT->Del_Record(pLUT->Get_Record_Count() - 1);
-			}
-
-			Parms("COLORS_TYPE")	->Set_Value(1);	// Color Classification Type: Lookup Table
-			Parms("LUT_ATTRIB")		->Set_Value(clustField);
-
-			DataObject_Set_Parameters(pResult, Parms);
 		}
-
-		//-------------------------------------------------
-		for( i=0; i<nCluster; i++ )
+		else
 		{
-			SG_Free(Centroids[i]);
+			for( int j=0; j<m_nFeatures; j++ )
+			{
+				vValues.at(j).push_back(pPC_in->Get_NoData_Value());
+			}
 		}
-
-		SG_Free(Centroids);
-		SG_Free(Variances);
-		SG_Free(nMembers);
-
-		vFields.clear();
-		vValues.clear();
-
-		return( true );
 	}
 
-	return( false );
+
+	nMembers	= (int     *)SG_Malloc(nCluster * sizeof(int));
+	Variances	= (double  *)SG_Malloc(nCluster * sizeof(double));
+	Centroids	= (double **)SG_Malloc(nCluster * sizeof(double *));
+
+	for( int i=0; i<nCluster; i++ )
+	{
+		Centroids[i]	= (double  *)SG_Malloc(m_nFeatures * sizeof(double));
+	}
+
+	//-------------------------------------------------
+	nElements	= pPC_in->Get_Point_Count();
+
+	switch( Parameters("METHOD")->asInt() )
+	{
+	case 0:
+		SP	= MinimumDistance	(nElements, nCluster);
+		break;
+
+	case 1:
+		SP	= HillClimbing		(nElements, nCluster);
+		break;
+
+	case 2:
+		SP	= MinimumDistance	(nElements, nCluster);
+
+		nElements	= pPC_in->Get_Point_Count();	// may have been diminished because of no data values...
+
+		SP	= HillClimbing		(nElements, nCluster);
+		break;
+	}
+
+	//-------------------------------------------------
+	if( Parameters("NORMALISE")->asBool() )
+	{
+		int		iv = 0;
+
+		for( int i=0; i<m_nFeatures; i++ )
+		{
+			for( int j=0; j<nCluster; j++ )
+			{
+				Centroids[j][iv]	= sqrt(pPC_in->Get_Variance(m_Features[i])) * Centroids[j][iv] + pPC_in->Get_Mean(m_Features[i]);
+			}
+
+			iv++;
+		}
+	}
+
+	Write_Result(Parameters("STATISTICS")->asTable(), nElements, nCluster, SP);
+
+	//-------------------------------------------------
+	for( int i=0; i<nCluster; i++ )
+	{
+		SG_Free(Centroids[i]);
+	}
+
+	SG_Free(Centroids);
+	SG_Free(Variances);
+	SG_Free(nMembers);
+
+	vValues.clear();
+
+	//-----------------------------------------------------
+	if (pPC_out == &PC_out)
+	{
+		CSG_MetaData	History	= pPC_in->Get_History();
+		CSG_String		sName	= pPC_in->Get_Name();
+
+		pPC_in->Assign(pPC_out);
+
+		pPC_in->Get_History() = History;
+		pPC_in->Set_Name(sName);
+
+		Parameters("PC_OUT")->Set_Value(pPC_in);
+	}
+	else
+	{
+		pPC_out->Set_Name(CSG_String::Format(SG_T("%s_cluster"), pPC_in->Get_Name()));
+	}
+	
+
+	return( true );
 }
 
 
@@ -441,13 +349,12 @@ bool CPC_Cluster_Analysis::On_Execute(void)
 //---------------------------------------------------------
 void CPC_Cluster_Analysis::Write_Result(CSG_Table *pTable, long nElements, int nCluster, double SP)
 {
-	int					i, j, cntField;
 	CSG_String			s;
 	CSG_Table_Record	*pRecord;
 
 	pTable->Destroy();
 	s	= CSG_String::Format(_TL("Cluster Analysis PC"));
-	s	+= CSG_String::Format(SG_T("_%s"), pInput->Get_Name());
+	s	+= CSG_String::Format(SG_T("_%s"), pPC_in->Get_Name());
 	pTable->Set_Name(s);
 
 	pTable->Add_Field(_TL("ClusterID")	, SG_DATATYPE_Int);
@@ -456,28 +363,22 @@ void CPC_Cluster_Analysis::Write_Result(CSG_Table *pTable, long nElements, int n
 
 	s.Printf(SG_T("\n%s:\t%ld \n%s:\t%d \n%s:\t%d \n%s:\t%f"),
 		_TL("Number of Elements")			, nElements,
-		_TL("\nNumber of Variables")		, nFields,
+		_TL("\nNumber of Variables")		, m_nFeatures,
 		_TL("\nNumber of Clusters")			, nCluster,
 		_TL("\nValue of Target Function")	, SP
 	);
 
 	s.Append(CSG_String::Format(SG_T("%s\t%s\t%s"), _TL("Cluster"), _TL("Elements"), _TL("Variance")));
 
-	cntField	= 1;
-
-	for( j=0; j<(int)vFields.size(); j++ )
+	for( int j=0; j<m_nFeatures; j++ )
 	{
-		if( vFields.at(j) )
-		{
-			s.Append(CSG_String::Format(SG_T("\t%02d_%s"), cntField, pInput->Get_Field_Name(j)));
-			pTable->Add_Field(pInput->Get_Field_Name(j), SG_DATATYPE_Double);
-			cntField++;
-		}
+		s.Append(CSG_String::Format(SG_T("\t%02d_%s"), j + 1, pPC_in->Get_Field_Name(m_Features[j])));
+		pTable->Add_Field(pPC_in->Get_Field_Name(m_Features[j]), SG_DATATYPE_Double);
 	}
 
 	Message_Add(s);
 
-	for( i=0; i<nCluster; i++ )
+	for( int i=0; i<nCluster; i++ )
 	{
 		s.Printf(SG_T("%d\t%d\t%f"), i, nMembers[i], Variances[i]);
 
@@ -486,7 +387,7 @@ void CPC_Cluster_Analysis::Write_Result(CSG_Table *pTable, long nElements, int n
 		pRecord->Set_Value(1, nMembers[i]);
 		pRecord->Set_Value(2, Variances[i]);
 
-		for( j=0; j<nFields; j++ )
+		for( int j=0; j<m_nFeatures; j++ )
 		{
 			s.Append(CSG_String::Format(SG_T("\t%f"), Centroids[i][j]));
 
@@ -523,33 +424,12 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 
 	for( iElement=0, nClusterElements=0; iElement<nElements; iElement++ )
 	{
-		/*for( iField=0, bContinue=true; iField<nFields && bContinue; iField++)
+		if( pPC_out->Get_Value(iElement, clustField) < 0 || pPC_out->Get_Value(iElement, clustField) >= nCluster )
 		{
-			if( Grids[iGrid]->is_NoData(iElement) )
-			{
-				bContinue	= false;
-			}
-		}*/
-		bContinue	= true;
-
-		if( bContinue )
-		{
-			if( pResult->Get_Value(iElement, clustField) < 0 || pResult->Get_Value(iElement, clustField) >= nCluster )
-			{
-				pResult->Set_Value(iElement, clustField, iElement % nCluster);
-			}
-
-			nClusterElements++;
+			pPC_out->Set_Value(iElement, clustField, iElement % nCluster);
 		}
-		else
-		{
-			pResult->Set_Value(iElement, clustField, -1);
-		}
-	}
 
-	if( Parameters("UPDATEVIEW")->asBool() )
-	{
-		DataObject_Update(pResult);
+		nClusterElements++;
 	}
 
 
@@ -564,7 +444,7 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 			Variances[iCluster]	= 0;
 			nMembers [iCluster]	= 0;
 
-			for( iField=0; iField<nFields; iField++ )
+			for( iField=0; iField<m_nFeatures; iField++ )
 			{
 				Centroids[iCluster][iField]	= 0;
 			}
@@ -573,12 +453,12 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 		//-------------------------------------------------
 		for( iElement=0; iElement<nElements; iElement++ )
 		{
-			if( pResult->Get_Value(iElement, clustField) >= 0 )
+			if( pPC_out->Get_Value(iElement, clustField) >= 0 )
 			{
-				iCluster	= (int)pResult->Get_Value(iElement, clustField);
+				iCluster	= (int)pPC_out->Get_Value(iElement, clustField);
 				nMembers[iCluster]++;
 
-				for( iField=0; iField<nFields; iField++ )
+				for( iField=0; iField<m_nFeatures; iField++ )
 				{
 					Centroids[iCluster][iField]	+= vValues.at(iField).at(iElement);
 				}
@@ -590,7 +470,7 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 		{
 			d		= nMembers[iCluster] > 0 ? 1.0 / (double)nMembers[iCluster] : 0;
 
-			for( iField=0; iField<nFields; iField++ )
+			for( iField=0; iField<m_nFeatures; iField++ )
 			{
 				Centroids[iCluster][iField]	*= d;
 			}
@@ -610,7 +490,7 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 				bContinue	= false;
 			}
 
-			if( pResult->Get_Value(iElement, clustField) >= 0 )
+			if( pPC_out->Get_Value(iElement, clustField) >= 0 )
 			{
 				minVariance	= -1;
 
@@ -618,7 +498,7 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 				{
 					Variance	= 0;
 
-					for( iField=0; iField<nFields; iField++ )
+					for( iField=0; iField<m_nFeatures; iField++ )
 					{
 						d			= Centroids[iCluster][iField] - vValues.at(iField).at(iElement);
 						Variance	+= d * d;
@@ -631,9 +511,9 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 					}
 				}
 
-				if( pResult->Get_Value(iElement, clustField) != minCluster )
+				if( pPC_out->Get_Value(iElement, clustField) != minCluster )
 				{
-					pResult->Set_Value(iElement, clustField, minCluster);
+					pPC_out->Set_Value(iElement, clustField, minCluster);
 					nShifts++;
 				}
 
@@ -656,11 +536,6 @@ double CPC_Cluster_Analysis::MinimumDistance(long &nElements, int nCluster)
 		));
 
 		SP_Last		= SP;
-
-		if( Parameters("UPDATEVIEW")->asBool() )
-		{
-			DataObject_Update(pResult);
-		}
 	}
 
 	nElements	= nClusterElements;
@@ -693,7 +568,7 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 		Variances[iCluster]	= 0;
 		nMembers [iCluster]	= 0;
 
-		for( iField=0; iField<nFields; iField++)
+		for( iField=0; iField<m_nFeatures; iField++)
 		{
 			Centroids[iCluster][iField]	= 0;
 		}
@@ -705,43 +580,27 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 
 	for( iElement=0, nClusterElements=0; iElement<nElements; iElement++ )
 	{
-		/*for( iField=0, bContinue=true; iField<nFields && bContinue; iField++)
+		if( pPC_out->Get_Value(iElement, clustField) < 0 || pPC_out->Get_Value(iElement, clustField) >= nCluster )
 		{
-			if( Grids[iGrid]->is_NoData(iElement) )
-			{
-				bContinue	= false;
-			}
-		}*/
-		bContinue	= true;
+			pPC_out->Set_Value(iElement, clustField, iElement % nCluster);
+		}
 
-		if( bContinue )
-		{
-			if( pResult->Get_Value(iElement, clustField) < 0 || pResult->Get_Value(iElement, clustField) >= nCluster )
-			{
-				pResult->Set_Value(iElement, clustField, iElement % nCluster);
-			}
-
-			nClusterElements++;
+		nClusterElements++;
 		
-			iCluster	= (int)pResult->Get_Value(iElement, clustField);
+		iCluster	= (int)pPC_out->Get_Value(iElement, clustField);
 
-			nMembers[iCluster]++;
+		nMembers[iCluster]++;
 
-			V			= 0.0;
+		V			= 0.0;
 
-			for( iField=0; iField<nFields; iField++)
-			{
-				d							 = vValues.at(iField).at(iElement);
-				Centroids[iCluster][iField]	+= d;
-				V							+= d * d;
-			}
-
-			Variances[iCluster]	+= V;
-		}
-		else
+		for( iField=0; iField<m_nFeatures; iField++)
 		{
-			pResult->Set_Value(iElement, clustField, -1);
+			d							 = vValues.at(iField).at(iElement);
+			Centroids[iCluster][iField]	+= d;
+			V							+= d * d;
 		}
+
+		Variances[iCluster]	+= V;
 	}
 
 
@@ -754,7 +613,7 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 		d	= nMembers[iCluster] != 0 ? 1.0 / (double)nMembers[iCluster] : 0;
 		V	= 0.0;
 
-		for( iField=0; iField<nFields; iField++)
+		for( iField=0; iField<m_nFeatures; iField++)
 		{
 			Centroids[iCluster][iField]	*= d;
 			e							 = Centroids[iCluster][iField];
@@ -765,11 +624,6 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 		SP					+= Variances[iCluster];
 	}
 
-	if( Parameters("UPDATEVIEW")->asBool() )
-	{
-		DataObject_Update(pResult);
-	}
-
 
 	//-----------------------------------------------------
 	// Hauptschleife der Iteration
@@ -786,7 +640,7 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 				bContinue	= false;
 			}
 
-			if( pResult->Get_Value(iElement, clustField) >= 0 )
+			if( pPC_out->Get_Value(iElement, clustField) >= 0 )
 			{
 				if( noShift++ >= nElements )
 				{
@@ -796,13 +650,13 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 				{
 
 					//---------------------------------------------
-					iCluster	= (int)pResult->Get_Value(iElement, clustField);
+					iCluster	= (int)pPC_out->Get_Value(iElement, clustField);
 
 					if( nMembers[iCluster] > 1 )
 					{
 						V	= 0.0;
 
-						for( iField=0; iField<nFields; iField++)
+						for( iField=0; iField<m_nFeatures; iField++)
 						{
 							d	= Centroids[iCluster][iField] - vValues.at(iField).at(iElement);
 							V	+= d * d;
@@ -821,7 +675,7 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 							{
 								V	= 0.0;
 
-								for( iField=0; iField<nFields; iField++)
+								for( iField=0; iField<m_nFeatures; iField++)
 								{
 									d	= Centroids[jCluster][iField] - vValues.at(iField).at(iElement);
 									V	+= d * d;
@@ -852,14 +706,14 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 							n_jK				= nMembers[kCluster];
 							V2					= 1.0 / (n_jK + 1.0);
 
-							for( iField=0; iField<nFields; iField++)
+							for( iField=0; iField<m_nFeatures; iField++)
 							{
 								d							= vValues.at(iField).at(iElement);
 								Centroids[iCluster][iField]	= (n_iK * Centroids[iCluster][iField] - d) * V1;
 								Centroids[kCluster][iField]	= (n_jK * Centroids[kCluster][iField] + d) * V2;
 							}
 
-							pResult->Set_Value(iElement, clustField, kCluster);
+							pPC_out->Set_Value(iElement, clustField, kCluster);
 
 							nMembers[iCluster]--;
 							nMembers[kCluster]++;
@@ -875,11 +729,6 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 		));
 
 		SP_Last		= SP;
-
-		if( Parameters("UPDATEVIEW")->asBool() )
-		{
-			DataObject_Update(pResult);
-		}
 	}
 
 	nElements	= nClusterElements;
@@ -887,6 +736,56 @@ double CPC_Cluster_Analysis::HillClimbing(long &nElements, int nCluster)
 	return( SP );
 }
 
+//---------------------------------------------------------
+bool CPC_Cluster_Analysis::On_After_Execution(void)
+{
+	CSG_PointCloud	*pPC_out	= Parameters("PC_OUT")->asPointCloud();
+
+	if (pPC_out == NULL)
+	{
+		pPC_out = Parameters("PC_IN")->asPointCloud();
+	}
+
+	CSG_Parameters	Parms;
+
+	if( DataObject_Get_Parameters(pPC_out, Parms) && Parms("COLORS_TYPE") && Parms("LUT") && Parms("LUT_ATTRIB") )
+	{
+		CSG_Table_Record	*pClass;
+		CSG_Table			*pLUT	= Parms("LUT")->asTable();
+
+		for( int i=0; i<=pPC_out->Get_Maximum(pPC_out->Get_Field_Count()-1); i++ )
+		{
+			if( (pClass = pLUT->Get_Record(i)) == NULL )
+			{
+				pClass	= pLUT->Add_Record();
+				pClass->Set_Value(0, SG_GET_RGB(rand() * 255.0 / RAND_MAX, rand() * 255.0 / RAND_MAX, rand() * 255.0 / RAND_MAX));
+			}
+
+			pClass->Set_Value(1, CSG_String::Format(SG_T("%s %d"), _TL("Class"), i));
+			pClass->Set_Value(2, CSG_String::Format(SG_T("%s %d"), _TL("Class"), i));
+			pClass->Set_Value(3, i);
+			pClass->Set_Value(4, i);
+		}
+
+		while( pLUT->Get_Record_Count() > (pPC_out->Get_Maximum(pPC_out->Get_Field_Count()-1) + 1) )
+		{
+			pLUT->Del_Record(pLUT->Get_Record_Count() - 1);
+		}
+
+		Parms("COLORS_TYPE")	->Set_Value(1);	// Color Classification Type: Lookup Table
+		Parms("LUT_ATTRIB")		->Set_Value(clustField);
+
+		DataObject_Set_Parameters(pPC_out, Parms);
+	}
+
+
+	if (pPC_out == Parameters("PC_IN")->asPointCloud())
+	{
+		Parameters("PC_OUT")->Set_Value(DATAOBJECT_NOTSET);
+	}
+
+	return (true);
+}
 
 ///////////////////////////////////////////////////////////
 //														 //
