@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: pc_drop_attribute.cpp 2891 2016-04-13 12:33:23Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -167,7 +167,12 @@ bool CPC_Drop_Attribute::On_Execute(void)
 				continue;
 			}
 
-			pOutput->Set_Attribute(k, pInput->Get_Attribute(i, j));
+			switch (pInput->Get_Attribute_Type(j))
+			{
+			default:					pOutput->Set_Attribute(k, pInput->Get_Attribute(i, j));		break;
+			case SG_DATATYPE_Date:
+			case SG_DATATYPE_String:	CSG_String sAttr; pInput->Get_Attribute(i, j, sAttr); pOutput->Set_Attribute(k, sAttr);		break;
+			}
 		}
 	}
 
@@ -181,6 +186,8 @@ bool CPC_Drop_Attribute::On_Execute(void)
 
 		pInput->Get_History() = History;
 		pInput->Set_Name(Name);
+
+		Parameters("OUTPUT")->Set_Value(pInput);
 	}
 	else
 	{
@@ -210,10 +217,18 @@ bool CPC_Drop_Attribute::On_After_Execution(void)
 	DataObject_Set_Parameter(pOutput, "METRIC_COLORS"          , 12);	// number of colors
 	DataObject_Set_Parameter(pOutput, "COLORS_TYPE"            ,  3);	// graduated color
 	DataObject_Set_Parameter(pOutput, "METRIC_ATTRIB"          ,  2);	// z attrib
-	DataObject_Set_Parameter(pOutput, "METRIC_ZRANGE", 100, 300);
+	DataObject_Set_Parameter(pOutput, "METRIC_ZRANGE",
+		pOutput->Get_Mean(2) - 2.0 * pOutput->Get_StdDev(2),
+		pOutput->Get_Mean(2) + 2.0 * pOutput->Get_StdDev(2)
+	);
 
 	DataObject_Set_Colors(pOutput, 11, SG_COLORS_RAINBOW);
 
+	if( pOutput == Parameters("INPUT")->asPointCloud() )
+	{
+		Parameters("OUTPUT")->Set_Value(DATAOBJECT_NOTSET);
+	}
+
 	return( true );
 }
 
