@@ -91,7 +91,7 @@ private:
 
 	double					is_Left				(const TSG_Point &Line_A, const TSG_Point &Line_B, const TSG_Point &Point);
 
-	bool					Get_Chain_Hull		(CSG_Shapes *pPoints, CSG_Shapes *pHulls);
+	bool					Get_Chain_Hull		(CSG_Shapes *pPoints, CSG_Shapes *pHulls, CSG_Shape *pAttributes = NULL);
 	int						Get_Chain_Hull		(CSG_Points &P, CSG_Points &H);
 
 	bool					Get_Bounding_Box	(CSG_Shape *pHull, CSG_Shape *pBox);
