@@ -108,6 +108,7 @@ CSG_String Get_Info(int i)
 #include "grid_pca.h"
 #include "multiband_variation.h"
 #include "grid_latlon_statistics.h"
+#include "categorical_variation.h"
 
 
 //---------------------------------------------------------
@@ -131,9 +132,11 @@ CSG_Module *		Create_Module(int i)
 	case 11:	return( new CGrid_Statistics_Latitudinal );
 	case 12:	return( new CGrid_Statistics_Meridional );
 	case 13:	return( new CGSGrid_Statistics_To_Table );
-	}
+	case 14:	return( new CCategorical_Variation );
 
-	return( NULL );
+	case 15:	return( NULL );
+	default:	return( MLB_INTERFACE_SKIP_MODULE );
+	}
 }
 
 
