@@ -76,8 +76,8 @@
 CKriging_Base::CKriging_Base(void)
 {
 	CSG_Parameter	*pNode;
-	CSG_Parameters	*pParameters;
 
+	///////////////////////////////////////////////////////
 	//-----------------------------------------------------
 	pNode	= Parameters.Add_Shapes(
 		NULL	, "POINTS"		, _TL("Points"),
@@ -86,10 +86,11 @@ CKriging_Base::CKriging_Base(void)
 	);
 
 	Parameters.Add_Table_Field(
-		pNode	, "ZFIELD"		, _TL("Attribute"),
+		pNode	, "FIELD"		, _TL("Attribute"),
 		_TL("")
 	);
 
+	///////////////////////////////////////////////////////
 	//-----------------------------------------------------
 	Parameters.Add_Choice(
 		NULL	, "TQUALITY"	, _TL("Type of Quality Measure"),
@@ -100,7 +101,6 @@ CKriging_Base::CKriging_Base(void)
 		), 0
 	);
 
-	//-----------------------------------------------------
 	Parameters.Add_Value(
 		NULL	, "LOG"			, _TL("Logarithmic Transformation"),
 		_TL(""),
@@ -110,97 +110,110 @@ CKriging_Base::CKriging_Base(void)
 	pNode	= Parameters.Add_Value(
 		NULL	, "BLOCK"		, _TL("Block Kriging"),
 		_TL(""),
-		PARAMETER_TYPE_Bool		, false
+		PARAMETER_TYPE_Bool, false
 	);
 
 	Parameters.Add_Value(
 		pNode	, "DBLOCK"		, _TL("Block Size"),
 		_TL(""),
-		PARAMETER_TYPE_Double	, 100.0, 0.0, true
+		PARAMETER_TYPE_Double, 100.0, 0.0, true
 	);
 
 	///////////////////////////////////////////////////////
 	//-----------------------------------------------------
+	Parameters.Add_Value(
+		NULL	, "VAR_MAXDIST"		, _TL("Maximum Distance"),
+		_TL(""),
+		PARAMETER_TYPE_Double, -1.0
+	)->Set_UseInGUI(false);
+
+	Parameters.Add_Value(
+		NULL	, "VAR_NCLASSES"	, _TL("Lag Distance Classes"),
+		_TL("initial number of lag distance classes"),
+		PARAMETER_TYPE_Int, 100, 1, true
+	)->Set_UseInGUI(false);
+
+	Parameters.Add_Value(
+		NULL	, "VAR_NSKIP"		, _TL("Skip"),
+		_TL(""),
+		PARAMETER_TYPE_Int, 1, 1, true
+	)->Set_UseInGUI(false);
+
+	Parameters.Add_String(
+		NULL	, "VAR_MODEL"		, _TL("Model"),
+		_TL(""),
+		SG_T("a + b * x")
+	)->Set_UseInGUI(false);
+
 	if( !SG_UI_Get_Window_Main() )
 	{
-		Parameters.Add_Value(
-			NULL	, "VAR_MAXDIST"		, _TL("Maximum Distance"),
-			_TL(""),
-			PARAMETER_TYPE_Double	, -1.0
-		);
-
-		Parameters.Add_Value(
-			NULL	, "VAR_NCLASSES"	, _TL("Lag Distance Classes"),
-			_TL("initial number of lag distance classes"),
-			PARAMETER_TYPE_Int		, 100, 1, true
-		);
-
-		Parameters.Add_Value(
-			NULL	, "VAR_NSKIP"		, _TL("Skip"),
-			_TL(""),
-			PARAMETER_TYPE_Int, 1, 1, true
-		);
-
-		Parameters.Add_String(
-			NULL	, "VAR_MODEL"		, _TL("Model"),
-			_TL(""),
-			SG_T("a + b * x")
-		);
+		m_pVariogram	= NULL;
+	}
+	else
+	{
+		m_pVariogram	= new CVariogram_Dialog;
 	}
 
 	///////////////////////////////////////////////////////
 	//-----------------------------------------------------
-	m_Grid_Target.Create(SG_UI_Get_Window_Main() ? &Parameters : Add_Parameters("TARGET", _TL("Target System"), _TL("")), false);
+	m_Grid_Target.Create(&Parameters, false, NULL, "TARGET_");
 
 	m_Grid_Target.Add_Grid("PREDICTION", _TL("Prediction"     ), false);
 	m_Grid_Target.Add_Grid("VARIANCE"  , _TL("Quality Measure"), true);
+
+	//-----------------------------------------------------
+	m_Search.Create(&Parameters, Parameters.Add_Node(NULL, "NODE_SEARCH", _TL("Search Options"), _TL("")), 16);
+}
+
+///////////////////////////////////////////////////////////
+//---------------------------------------------------------
+CKriging_Base::~CKriging_Base(void)
+{
+	if( m_pVariogram && SG_UI_Get_Window_Main() )	// don't destroy dialog, if gui is closing (i.e. main window == NULL)
+	{
+		m_pVariogram->Destroy();
+
+		delete(m_pVariogram);
+	}
 }
 
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 int CKriging_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "POINTS") && pParameter->asShapes() )
+	if( !SG_STR_CMP(pParameter->Get_Identifier(), "POINTS") )
 	{
-		m_Grid_Target.Set_User_Defined(pParameters, pParameter->asShapes()->Get_Extent());
+		m_Search.On_Parameter_Changed(pParameters, pParameter);
+
+		m_Grid_Target.Set_User_Defined(pParameters, pParameter->asShapes());
 	}
 
-	return( m_Grid_Target.On_Parameter_Changed(pParameters, pParameter) ? 1 : 0 );
+	m_Grid_Target.On_Parameter_Changed(pParameters, pParameter);
+
+	return( CSG_Module::On_Parameter_Changed(pParameters, pParameter) );
 }
 
 //---------------------------------------------------------
 int CKriging_Base::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SEARCH_RANGE") )
-	{
-		pParameters->Set_Enabled("SEARCH_RADIUS"    , pParameter->asInt() == 0);	// local
-	}
-
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SEARCH_POINTS_ALL") )
-	{
-		pParameters->Set_Enabled("SEARCH_POINTS_MAX", pParameter->asInt() == 0);	// maximum number of points
-		pParameters->Set_Enabled("SEARCH_DIRECTION" , pParameter->asInt() == 0);	// maximum number of points per quadrant
-	}
-
 	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "BLOCK") )
 	{
-		pParameters->Set_Enabled("DBLOCK"           , pParameter->asBool()    );	// block size
+		pParameters->Set_Enabled("DBLOCK", pParameter->asBool());	// block size
 	}
 
-	return( m_Grid_Target.On_Parameters_Enable(pParameters, pParameter) ? 1 : 0 );
+	m_Search     .On_Parameters_Enable(pParameters, pParameter);
+	m_Grid_Target.On_Parameters_Enable(pParameters, pParameter);
+
+	return( CSG_Module::On_Parameters_Enable(pParameters, pParameter) );
 }
 
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -214,7 +227,7 @@ bool CKriging_Base::On_Execute(void)
 	m_bLog		= Parameters("LOG"     )->asBool();
 
 	m_pPoints	= Parameters("POINTS"  )->asShapes();
-	m_zField	= Parameters("ZFIELD"  )->asInt();
+	m_zField	= Parameters("FIELD"   )->asInt();
 
 	if( m_pPoints->Get_Count() <= 1 )
 	{
@@ -226,11 +239,9 @@ bool CKriging_Base::On_Execute(void)
 	//-----------------------------------------------------
 	CSG_Table	Variogram;
 
-	if( SG_UI_Get_Window_Main() )
+	if( m_pVariogram )
 	{
-		static CVariogram_Dialog	dlg;
-
-		if( dlg.Execute(m_pPoints, m_zField, m_bLog, &Variogram, &m_Model) )
+		if( m_pVariogram->Execute(m_pPoints, m_zField, m_bLog, &Variogram, &m_Model) )
 		{
 			bResult	= true;
 		}
@@ -283,9 +294,10 @@ bool CKriging_Base::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	m_Model.Clr_Data();
-
-	On_Finalize();
+	m_Model .Clr_Data();
+	m_Search.Finalize();
+	m_Data  .Clear();
+	m_W     .Destroy();
 
 	return( bResult );
 }
@@ -293,22 +305,18 @@ bool CKriging_Base::On_Execute(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CKriging_Base::_Initialise_Grids(void)
 {
-	m_Grid_Target.Set_User_Defined(Get_Parameters("TARGET"), m_pPoints->Get_Extent());	Dlg_Parameters("TARGET");	// if called from saga_cmd
-
 	if( (m_pGrid = m_Grid_Target.Get_Grid("PREDICTION")) != NULL )
 	{
-		m_pGrid->Set_Name(CSG_String::Format(SG_T("%s [%s]"), Parameters("ZFIELD")->asString(), Get_Name().c_str()));
+		m_pGrid->Set_Name(CSG_String::Format(SG_T("%s.%s [%s]"), Parameters("POINTS")->asShapes()->Get_Name(), Parameters("FIELD")->asString(), Get_Name().c_str()));
 
 		if( (m_pVariance = m_Grid_Target.Get_Grid("VARIANCE")) != NULL )
 		{
-			m_pVariance->Set_Name(CSG_String::Format(SG_T("%s [%s %s]"), Parameters("ZFIELD")->asString(), Get_Name().c_str(), m_bStdDev ? _TL("Standard Deviation") : _TL("Variance")));
+			m_pVariance->Set_Name(CSG_String::Format(SG_T("%s.%s [%s %s]"), Parameters("POINTS")->asShapes()->Get_Name(), Parameters("FIELD")->asString(), Get_Name().c_str(), m_bStdDev ? _TL("Standard Deviation") : _TL("Variance")));
 		}
 
 		return( true );
@@ -318,6 +326,54 @@ bool CKriging_Base::_Initialise_Grids(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CKriging_Base::On_Initialize(void)
+{
+	//-----------------------------------------------------
+	if( m_Search.Do_Use_All(true) )	// global
+	{
+		m_Data.Clear();
+
+		for(int i=0; i<m_pPoints->Get_Count(); i++)
+		{
+			CSG_Shape	*pPoint	= m_pPoints->Get_Shape(i);
+
+			if( !pPoint->is_NoData(m_zField) )
+			{
+				m_Data.Add(pPoint->Get_Point(0).x, pPoint->Get_Point(0).y, m_bLog ? log(pPoint->asDouble(m_zField)) : pPoint->asDouble(m_zField));
+			}
+		}
+
+		return( Get_Weights(m_Data, m_W) );
+	}
+
+	//-----------------------------------------------------
+	if( m_bLog )
+	{
+		CSG_Shapes	Points(SHAPE_TYPE_Point); Points.Add_Field("Z", SG_DATATYPE_Double);
+
+		for(int i=0; i<m_pPoints->Get_Count() && Set_Progress(i, m_pPoints->Get_Count()); i++)
+		{
+			CSG_Shape	*pPoint	= m_pPoints->Get_Shape(i);
+
+			if( !pPoint->is_NoData(m_zField) )
+			{
+				Points.Add_Shape(pPoint, SHAPE_COPY_GEOM)->Set_Value(0, log(pPoint->asDouble(m_zField)));
+			}
+		}
+
+		return( m_Search.Initialize(&Points, 0) );
+	}
+
+	//-----------------------------------------------------
+	return( m_Search.Initialize(m_pPoints, m_zField) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
