@@ -76,7 +76,7 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 	CSG_Parameter	*pNode;
 
 	//-----------------------------------------------------
-	Set_Name		(_TL("Multiple Regression Analysis (Points/Grids)"));
+	Set_Name		(_TL("Multiple Regression Analysis (Points and Predictor Grids)"));
 
 	Set_Author		("O.Conrad (c) 2004");
 
@@ -94,7 +94,7 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_Grid_List(
-		NULL	, "GRIDS"		, _TL("Grids"),
+		NULL	, "PREDICTORS"	, _TL("Predictors"),
 		_TL(""),
 		PARAMETER_INPUT, true
 	);
@@ -106,7 +106,7 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 	);
 
 	Parameters.Add_Table_Field(
-		pNode	, "ATTRIBUTE"	, _TL("Attribute"),
+		pNode	, "ATTRIBUTE"	, _TL("Dependent Variable"),
 		_TL("")
 	);
 
@@ -136,20 +136,25 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 
 	Parameters.Add_Grid(
 		NULL	, "REGRESSION"	, _TL("Regression"),
-		_TL(""),
+		_TL("regression model applied to predictor grids"),
 		PARAMETER_OUTPUT
 	);
 
+	Parameters.Add_Grid(
+		NULL	, "REGRESCORR"	, _TL("Regression with Residual Correction"),
+		_TL("regression model applied to predictor grids with interpolated residuals added"),
+		PARAMETER_OUTPUT_OPTIONAL
+	);
+
 	Parameters.Add_Choice(
-		NULL	,"INTERPOL"		, _TL("Grid Interpolation"),
+		NULL	, "RESAMPLING"	, _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|%s|"),
-			_TL("Nearest Neighbor"),
+		CSG_String::Format("%s|%s|%s|%s|",
+			_TL("Nearest Neighbour"),
 			_TL("Bilinear Interpolation"),
-			_TL("Inverse Distance Interpolation"),
 			_TL("Bicubic Spline Interpolation"),
 			_TL("B-Spline Interpolation")
-		), 4
+		), 3
 	);
 
 	Parameters.Add_Value(
@@ -182,14 +187,8 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 	);
 
 	Parameters.Add_Value(
-		NULL	, "P_IN"		, _TL("P in"),
-		_TL("Level of significance for automated predictor selection, given as percentage"),
-		PARAMETER_TYPE_Double, 5.0, 0.0, true, 100.0, true
-	);
-
-	Parameters.Add_Value(
-		NULL	, "P_OUT"		, _TL("P out"),
-		_TL("Level of significance for automated predictor selection, given as percentage"),
+		NULL	, "P_VALUE"		, _TL("Significance Level"),
+		_TL("Significance level (aka p-value) as threshold for automated predictor selection, given as percentage"),
 		PARAMETER_TYPE_Double, 5.0, 0.0, true, 100.0, true
 	);
 
@@ -209,6 +208,15 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 		_TL("number of subsamples for k-fold cross validation"),
 		PARAMETER_TYPE_Int, 10, 2, true
 	);
+
+	Parameters.Add_Choice(
+		NULL	,"RESIDUAL_COR"	, _TL("Residual Interpolation"),
+		_TL(""),
+		CSG_String::Format(SG_T("%s|%s|"),
+			_TL("Multleve B-Spline Interpolation"),
+			_TL("Inverse Distance Weighted")
+		), 0
+	);
 }
 
 
@@ -228,8 +236,12 @@ int CPoint_Multi_Grid_Regression::On_Parameters_Enable(CSG_Parameters *pParamete
 
 	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METHOD") )
 	{
-		pParameters->Set_Enabled("P_IN" , pParameter->asInt() == 1 || pParameter->asInt() == 3);
-		pParameters->Set_Enabled("P_OUT", pParameter->asInt() == 2 || pParameter->asInt() == 3);
+		pParameters->Set_Enabled("P_VALUE", pParameter->asInt() > 0);
+	}
+
+	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "REGRESCORR") )
+	{
+		pParameters->Set_Enabled("RESIDUAL_COR", pParameter->asGrid() != NULL);
 	}
 
 	return( 0 );
@@ -247,7 +259,7 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 {
 	bool					bResult;
 	int						iAttribute;
-	double					P_in, P_out;
+	double					P;
 	CSG_Strings				Names;
 	CSG_Matrix				Samples;
 	CSG_Shapes				*pPoints;
@@ -255,12 +267,11 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	CSG_Parameter_Grid_List	*pGrids;
 
 	//-----------------------------------------------------
-	pGrids		= Parameters("GRIDS"     )->asGridList();
+	pGrids		= Parameters("PREDICTORS")->asGridList();
 	pRegression	= Parameters("REGRESSION")->asGrid();
 	pPoints		= Parameters("POINTS"    )->asShapes();
 	iAttribute	= Parameters("ATTRIBUTE" )->asInt();
-	P_in		= Parameters("P_IN"      )->asDouble() / 100.0;
-	P_out		= Parameters("P_OUT"     )->asDouble() / 100.0;
+	P			= Parameters("P_VALUE"   )->asDouble() / 100.0;
 
 	//-----------------------------------------------------
 	if( !Get_Samples(pGrids, pPoints, iAttribute, Samples, Names) )
@@ -274,10 +285,10 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	switch( Parameters("METHOD")->asInt() )
 	{
 	default:
-	case 0:	bResult	= m_Regression.Get_Model         (Samples             , &Names);	break;
-	case 1:	bResult	= m_Regression.Get_Model_Forward (Samples, P_in       , &Names);	break;
-	case 2:	bResult	= m_Regression.Get_Model_Backward(Samples,       P_out, &Names);	break;
-	case 3:	bResult	= m_Regression.Get_Model_Stepwise(Samples, P_in, P_out, &Names);	break;
+	case 0:	bResult	= m_Regression.Get_Model         (Samples      , &Names);	break;
+	case 1:	bResult	= m_Regression.Get_Model_Forward (Samples, P   , &Names);	break;
+	case 2:	bResult	= m_Regression.Get_Model_Backward(Samples,    P, &Names);	break;
+	case 3:	bResult	= m_Regression.Get_Model_Stepwise(Samples, P, P, &Names);	break;
 	}
 
 	if( bResult == false )
@@ -312,9 +323,7 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	Set_Regression(pGrids, pRegression, CSG_String::Format(SG_T("%s [%s]"), Parameters("ATTRIBUTE")->asString(), _TL("Regression Model")));
-
-	Set_Residuals(pPoints, iAttribute, pRegression);
+	Set_Regression(pGrids, pRegression, CSG_String::Format("%s.%s [%s]", pPoints->Get_Name(), Parameters("ATTRIBUTE")->asString(), _TL("Regression")));
 
 	//-----------------------------------------------------
 	if( Parameters("INFO_COEFF")->asTable() )
@@ -336,6 +345,10 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
+	Set_Residuals(Parameters("RESIDUALS")->asShapes());
+
+	Set_Residual_Corr(pRegression, Parameters("RESIDUALS")->asShapes(), Parameters("REGRESCORR")->asGrid());
+
 	m_Regression.Destroy();
 
 	return( true );
@@ -356,9 +369,18 @@ bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids,
 	CSG_Vector	Sample;
 
 	//-----------------------------------------------------
-	int		Interpolation	= Parameters("INTERPOL")	->asInt();
-	bool	bCoord_X		= Parameters("COORD_X")		->asBool();
-	bool	bCoord_Y		= Parameters("COORD_Y")		->asBool();
+	bool	bCoord_X	= Parameters("COORD_X")->asBool();
+	bool	bCoord_Y	= Parameters("COORD_Y")->asBool();
+
+	TSG_Grid_Resampling	Resampling;
+
+	switch( Parameters("RESAMPLING")->asInt() )
+	{
+	default:	Resampling	= GRID_RESAMPLING_NearestNeighbour;	break;
+	case  1:	Resampling	= GRID_RESAMPLING_Bilinear;			break;
+	case  2:	Resampling	= GRID_RESAMPLING_BicubicSpline;	break;
+	case  3:	Resampling	= GRID_RESAMPLING_BSpline;			break;
+	}
 
 	Names	+= pPoints->Get_Field_Name(iAttribute);		// Dependent Variable
 
@@ -390,7 +412,7 @@ bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids,
 
 					for(iGrid=0; iGrid<pGrids->Get_Count() && bAdd; iGrid++)
 					{
-						if( pGrids->asGrid(iGrid)->Get_Value(Point, zGrid, Interpolation) )
+						if( pGrids->asGrid(iGrid)->Get_Value(Point, zGrid, Resampling) )
 						{
 							Sample[1 + iGrid]	= zGrid;
 						}
@@ -435,7 +457,15 @@ bool CPoint_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrid
 	int			iGrid, nGrids, x, y;
 	TSG_Point	p;
 
-	int		Interpolation	= Parameters("INTERPOL")	->asInt();
+	TSG_Grid_Resampling	Resampling;
+
+	switch( Parameters("RESAMPLING")->asInt() )
+	{
+	default:	Resampling	= GRID_RESAMPLING_NearestNeighbour;	break;
+	case  1:	Resampling	= GRID_RESAMPLING_Bilinear;			break;
+	case  2:	Resampling	= GRID_RESAMPLING_BicubicSpline;	break;
+	case  3:	Resampling	= GRID_RESAMPLING_BSpline;			break;
+	}
 
 	CSG_Grid	**ppGrids	= (CSG_Grid **)SG_Malloc(m_Regression.Get_nPredictors() * sizeof(CSG_Grid *));
 
@@ -472,7 +502,7 @@ bool CPoint_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrid
 			{
 				double	zGrid;
 
-				if( ppGrids[iGrid]->Get_Value(p, zGrid, Interpolation) )
+				if( ppGrids[iGrid]->Get_Value(p, zGrid, Resampling) )
 				{
 					z	+= m_Regression.Get_RCoeff(iGrid) * zGrid;
 				}
@@ -518,24 +548,35 @@ bool CPoint_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrid
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pPoints, int iAttribute, CSG_Grid *pRegression)
+bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pResiduals)
 {
-	CSG_Shapes	*pResiduals		= Parameters("RESIDUALS")->asShapes();
-
-	if( !pRegression || !pResiduals )
+	if( !pResiduals )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	pResiduals->Create(SHAPE_TYPE_Point, CSG_String::Format(SG_T("%s [%s]"), Parameters("ATTRIBUTE")->asString(), _TL("Residuals")));
+	CSG_Shapes	*pPoints		= Parameters("POINTS"    )->asShapes();
+	CSG_Grid	*pRegression	= Parameters("REGRESSION")->asGrid();
+	int			iAttribute		= Parameters("ATTRIBUTE" )->asInt();
+
+	TSG_Grid_Resampling	Resampling;
+
+	switch( Parameters("RESAMPLING")->asInt() )
+	{
+	default:	Resampling	= GRID_RESAMPLING_NearestNeighbour;	break;
+	case  1:	Resampling	= GRID_RESAMPLING_Bilinear;			break;
+	case  2:	Resampling	= GRID_RESAMPLING_BicubicSpline;	break;
+	case  3:	Resampling	= GRID_RESAMPLING_BSpline;			break;
+	}
+
+	//-----------------------------------------------------
+	pResiduals->Create(SHAPE_TYPE_Point, CSG_String::Format("%s.%s [%s]", pPoints->Get_Name(), Parameters("ATTRIBUTE")->asString(), _TL("Residuals")));
 	pResiduals->Add_Field(pPoints->Get_Field_Name(iAttribute), SG_DATATYPE_Double);
 	pResiduals->Add_Field("TREND"	, SG_DATATYPE_Double);
 	pResiduals->Add_Field("RESIDUAL", SG_DATATYPE_Double);
 
-	int	Interpolation	= Parameters("INTERPOL")->asInt();
-
-	//-------------------------------------------------
+	//-----------------------------------------------------
 	for(int iShape=0; iShape<pPoints->Get_Count() && Set_Progress(iShape, pPoints->Get_Count()); iShape++)
 	{
 		CSG_Shape	*pShape	= pPoints->Get_Shape(iShape);
@@ -551,7 +592,7 @@ bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pPoints, int iAttri
 					double		zGrid;
 					TSG_Point	Point	= pShape->Get_Point(iPoint, iPart);
 
-					if( pRegression->Get_Value(Point, zGrid, Interpolation) )
+					if( pRegression->Get_Value(Point, zGrid, Resampling) )
 					{
 						CSG_Shape	*pResidual	= pResiduals->Add_Shape();
 
@@ -569,6 +610,75 @@ bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pPoints, int iAttri
 	return( true );
 }
 
+//---------------------------------------------------------
+bool CPoint_Multi_Grid_Regression::Set_Residual_Corr(CSG_Grid *pRegression, CSG_Shapes *pResiduals, CSG_Grid *pCorrection)
+{
+	//-----------------------------------------------------
+	if( !pCorrection )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_Shapes	Residuals;
+
+	if( !pResiduals )
+	{
+		if( !Set_Residuals(&Residuals) )
+		{
+			return( false );
+		}
+
+		pResiduals	= &Residuals;
+	}
+
+	//-----------------------------------------------------
+	switch( Parameters("RESIDUAL_COR")->asInt() )
+	{
+	default:	// Multlevel B-Spline Interpolation
+		SG_RUN_MODULE_ExitOnError("grid_spline", 4,
+				SG_MODULE_PARAMETER_SET("SHAPES"           , pResiduals)
+			&&  SG_MODULE_PARAMETER_SET("FIELD"            , 2)
+			&&  SG_MODULE_PARAMETER_SET("TARGET_DEFINITION", 1)	// grid or grid system
+			&&  SG_MODULE_PARAMETER_SET("TARGET_OUT_GRID"  , pCorrection)
+		);
+		break;
+
+	case  1:	// Inverse Distance Weighted
+		SG_RUN_MODULE_ExitOnError("grid_gridding", 1,
+				SG_MODULE_PARAMETER_SET("SHAPES"           , pResiduals)
+			&&  SG_MODULE_PARAMETER_SET("FIELD"            , 2)
+			&&  SG_MODULE_PARAMETER_SET("TARGET_DEFINITION", 1)	// grid or grid system
+			&&  SG_MODULE_PARAMETER_SET("TARGET_OUT_GRID"  , pCorrection)
+			&&  SG_MODULE_PARAMETER_SET("SEARCH_RANGE"     , 1)	// global
+			&&  SG_MODULE_PARAMETER_SET("SEARCH_POINTS_ALL", 1)	// all points within search distance
+		);
+		break;
+	}
+
+	//-----------------------------------------------------
+	#pragma omp parallel for
+	for(int y=0; y<Get_NY(); y++)
+	{
+		for(int x=0; x<Get_NX(); x++)
+		{
+			if( pRegression->is_NoData(x, y) || pCorrection->is_NoData(x, y) )
+			{
+				pCorrection->Set_NoData(x, y);
+			}
+			else
+			{
+				pCorrection->Add_Value(x, y, pRegression->asDouble(x, y));
+			}
+		}
+	}
+
+	pCorrection->Set_Name(CSG_String::Format("%s.%s [%s]", Parameters("POINTS")->asShapes()->Get_Name(), Parameters("ATTRIBUTE")->asString(), _TL("Residual Corrected Regression")));
+
+	//-----------------------------------------------------
+	return( true );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
