@@ -91,7 +91,7 @@ CTA_Standard::CTA_Standard(void)
 	Parameters.Add_Grid  (NULL, "VCURV"      , _TL("Profile Curvature"         ), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Grid  (NULL, "CONVERGENCE", _TL("Convergence Index"         ), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Grid  (NULL, "SINKS"      , _TL("Closed Depressions"        ), _TL(""), PARAMETER_OUTPUT);
-	Parameters.Add_Grid  (NULL, "CAREA"      , _TL("Total Catchment Area"      ), _TL(""), PARAMETER_OUTPUT);
+	Parameters.Add_Grid  (NULL, "FLOW"       , _TL("Total Catchment Area"      ), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Grid  (NULL, "WETNESS"    , _TL("Topographic Wetness Index" ), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Grid  (NULL, "LSFACTOR"   , _TL("LS-Factor"                 ), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Shapes(NULL, "CHANNELS"   , _TL("Channel Network"           ), _TL(""), PARAMETER_OUTPUT, SHAPE_TYPE_Line);
@@ -177,14 +177,14 @@ bool CTA_Standard::On_Execute(void)
 	//-----------------------------------------------------
 	SG_RUN_MODULE_ExitOnError("ta_hydrology"       , 0,
 			SG_MODULE_PARAMETER_SET("ELEVATION"    , &DEMP)	// << preprocessed DEM
-		&&	SG_MODULE_PARAMETER_SET("CAREA"        , Parameters("CAREA"))
+		&&	SG_MODULE_PARAMETER_SET("FLOW"         , Parameters("FLOW"))
 		&&	SG_MODULE_PARAMETER_SET("METHOD"       , 4)		// MFD
 	)
 
 	//-----------------------------------------------------
 	SG_RUN_MODULE_ExitOnError("ta_hydrology"       , 19,
 			SG_MODULE_PARAMETER_SET("DEM"          , &DEMP)
-		&&	SG_MODULE_PARAMETER_SET("TCA"          , Parameters("CAREA"))
+		&&	SG_MODULE_PARAMETER_SET("TCA"          , Parameters("FLOW"))
 		&&	SG_MODULE_PARAMETER_SET("WIDTH"        , &TMP2)
 		&&	SG_MODULE_PARAMETER_SET("SCA"          , &TMP1)	// >> specific catchment area
 		&&	SG_MODULE_PARAMETER_SET("METHOD"       , 1)
@@ -224,20 +224,19 @@ bool CTA_Standard::On_Execute(void)
 	)
 
 	//-----------------------------------------------------
-	SG_RUN_MODULE_ExitOnError("grid_tools"         , 19,	// grid orientation
-			SG_MODULE_PARAMETER_SET("INPUT"        , &DEMP)
-		&&	SG_MODULE_PARAMETER_SET("RESULT"       , &TMP1)
-		&&	SG_MODULE_PARAMETER_SET("METHOD"       , 3)	// invert
+	SG_RUN_MODULE_ExitOnError("grid_tools"         , 34,	// invert grid
+			SG_MODULE_PARAMETER_SET("GRID"         , &DEMP)
+		&&	SG_MODULE_PARAMETER_SET("INVERSE"      , &TMP1)
 	)
 
-	SG_RUN_MODULE_ExitOnError("ta_channels"        , 6,	// strahler order
+	SG_RUN_MODULE_ExitOnError("ta_channels"        ,  6,	// strahler order
 			SG_MODULE_PARAMETER_SET("DEM"          , &TMP1)
 		&&	SG_MODULE_PARAMETER_SET("STRAHLER"     , &TMP2)
 	)
 
 	TMP2.Set_NoData_Value_Range(0, 4);
 
-	SG_RUN_MODULE_ExitOnError("ta_channels"        , 3,	// vertical channel network distance
+	SG_RUN_MODULE_ExitOnError("ta_channels"        ,  3,	// vertical channel network distance
 			SG_MODULE_PARAMETER_SET("ELEVATION"    , &TMP1)
 		&&	SG_MODULE_PARAMETER_SET("CHANNELS"     , &TMP2)
 		&&	SG_MODULE_PARAMETER_SET("DISTANCE"     , Parameters("VALL_DEPTH"))
@@ -245,7 +244,7 @@ bool CTA_Standard::On_Execute(void)
 
 	Parameters("VALL_DEPTH")->asGrid()->Set_Name(_TL("Valley Depth"));
 
-	SG_RUN_MODULE_ExitOnError("grid_calculus"      , 1,	// grid calculator
+	SG_RUN_MODULE_ExitOnError("grid_calculus"      ,  1,	// grid calculator
 			SG_MODULE_PARAMETER_SET("RESULT"       , Parameters("RSP"))
 		&&	SG_MODULE_PARAMETER_SET("FORMULA"      , SG_T("g1 / (g1 + g2)"))
 		&&	SG_MODULE_PARAMETER_SET("NAME"         , _TL("Relative Slope Position"))
