@@ -31,7 +31,7 @@ public:
 	CIsochronesConst(void);
 	virtual ~CIsochronesConst(void);
 
-	virtual CSG_String		Get_MenuPath	(void)	{	return( _TL("R:Dynamics" ));	}
+	virtual CSG_String		Get_MenuPath	(void)	{	return( _TL("Dynamics" ));	}
 
 protected:
 	virtual bool On_Execute(void);
