@@ -74,7 +74,7 @@
 CTIN_View_Module::CTIN_View_Module(void)
 {
 	//-----------------------------------------------------
-	Set_Name		(_TL("TIN Viewer"));
+	Set_Name		(_TL("[deprecated] TIN Viewer"));
 
 	Set_Author		(SG_T("O. Conrad (c) 2011"));
 
@@ -120,13 +120,6 @@ CTIN_View_Module::CTIN_View_Module(void)
 //---------------------------------------------------------
 bool CTIN_View_Module::On_Execute(void)
 {
-	if( !SG_UI_Get_Window_Main() )
-	{
-		Message_Add(_TL("point cloud viewer can only be run from graphical user interface"));
-
-		return( false );
-	}
-
 	CSG_TIN	*pTIN	= Parameters("TIN")->asTIN();
 
 	if( pTIN->Get_Count() <= 0 )
