@@ -74,8 +74,6 @@
 //---------------------------------------------------------
 #include "api_core.h"
 
-#include <limits.h>
-
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -211,7 +209,7 @@ public:
 
 	enum Year		// invalid value for the year
 	{
-		Inv_Year	= SHRT_MIN	// should hold in wxDateTime_t
+		Inv_Year	= -32768	// should hold in wxDateTime_t
 	};
 
 	enum NameFlags	// flags for GetWeekDayName and GetMonthName
@@ -382,6 +380,51 @@ SAGA_API_DLL_EXPORT bool		SG_Get_Sun_Position		(double   JulianDayNumber, double
 SAGA_API_DLL_EXPORT bool		SG_Get_Sun_Position		(const CSG_DateTime &Time, double Longitude, double Latitude, double &Height, double &Azimuth);
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+typedef enum ESG_Time_Format
+{
+	SG_TIME_FMT_Seconds_Unix	= 0,
+	SG_TIME_FMT_Hours_AD
+}
+TSG_Time_Format;
+
+//---------------------------------------------------------
+typedef enum ESG_Time_String_Format
+{
+	SG_TIME_STRFMT_YMD_hms		= 0,
+	SG_TIME_STRFMT_DMY_hms
+}
+TSG_Time_String_Format;
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Time_Converter
+{
+public:
+	CSG_Time_Converter(void);
+	CSG_Time_Converter(int Time, TSG_Time_Format Format);
+
+	bool						Set_Time		(int Time, TSG_Time_Format Format);
+
+	CSG_String					Get_String		(void)	const;
+
+	static CSG_String			Get_String		(int Time, TSG_Time_Format Format);
+
+
+public:
+
+	TSG_Time_String_Format		m_StrFmt;
+
+	int							m_sec, m_min, m_hour, m_day, m_mon, m_year;
+
+};
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
