@@ -248,7 +248,7 @@ bool CSG_Module_Chain::Create(const CSG_String &File)
 
 		case PARAMETER_TYPE_Date             : Parameters.Add_Date           (pParent, ID, Name, Desc, 0.0)->Set_Value(Value);	break;
 
-		case PARAMETER_TYPE_Range            : Parameters.Add_Range          (pParent, ID, Name, Desc, Value.BeforeFirst(';').asDouble(), Value.AfterFirst (';').asDouble(), Min, bMin, Max, bMax);	break;
+		case PARAMETER_TYPE_Range            : Parameters.Add_Range          (pParent, ID, Name, Desc, Value.BeforeFirst(';').asDouble(), Value.AfterFirst(';').asDouble(), Min, bMin, Max, bMax);	break;
 		case PARAMETER_TYPE_Choice           : Parameters.Add_Choice         (pParent, ID, Name, Desc, Parameter.Get_Content("choices"))->Set_Value(Value);	break;
 
 		case PARAMETER_TYPE_String           : Parameters.Add_String         (pParent, ID, Name, Desc, Value, false);	break;
@@ -387,7 +387,7 @@ bool CSG_Module_Chain::Data_Add(const CSG_String &ID, CSG_Parameter *pData)
 		return( true );
 
 	default:
-		return( false );
+		return( true );
 	}
 
 	pParameter->Assign(pData);
@@ -439,19 +439,20 @@ bool CSG_Module_Chain::Data_Initialize(void)
 {
 	m_Data.Set_Manager(NULL);
 
-	bool	bResult	= false;
-
 	for(int i=0; i<Parameters.Get_Count(); i++)
 	{
 		CSG_Parameter	*pParameter	= Parameters(i);
 
-		if( !(pParameter->is_DataObject() && !pParameter->asDataObject()) && Data_Add(pParameter->Get_Identifier(), pParameter) )
+		if( !(pParameter->is_DataObject() && !pParameter->asDataObject()) )
 		{
-			bResult	= true;
+			if( !Data_Add(pParameter->Get_Identifier(), pParameter) )
+			{
+				return( false );
+			}
 		}
 	}
 
-	return( bResult );
+	return( true );
 }
 
 //---------------------------------------------------------
@@ -723,6 +724,8 @@ bool CSG_Module_Chain::Tool_Run(const CSG_MetaData &Tool)
 		Error_Fmt("%s [%s].[%s]", _TL("tool execution failed"             ), pModule->Get_Library().c_str(), pModule->Get_Name().c_str());
 	}
 
+	pModule->On_After_Execution();
+
 	Tool_Finalize(Tool, pModule);
 
 	pModule->Settings_Pop();
