@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: parameters.cpp 2872 2016-03-30 16:28:26Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -1429,7 +1429,10 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 		//-------------------------------------------------
 		else
 		{
-			if( p->Get_Type() == PARAMETER_TYPE_Shapes && p->asShapes() && p->asShapes()->Get_Type() == SHAPE_TYPE_Undefined )
+			if( p->Get_Type() == PARAMETER_TYPE_Shapes
+			&&  p->asShapes() != DATAOBJECT_NOTSET
+			&&  p->asShapes() != DATAOBJECT_CREATE
+			&&  p->asShapes()->Get_Type() == SHAPE_TYPE_Undefined )
 			{
 				if( m_pManager && !m_pManager->Delete(p->asShapes()) )
 				{
@@ -1442,7 +1445,9 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 			//---------------------------------------------
 			if( p->is_Output() )
 			{
-				if( p->is_DataObject() && p->asDataObject() )
+				if( p->is_DataObject()
+				&&  p->asDataObject() != DATAOBJECT_NOTSET
+				&&  p->asDataObject() != DATAOBJECT_CREATE )
 				{
 					CSG_Data_Object	*pObject	= p->asDataObject();
 
@@ -1506,7 +1511,9 @@ bool CSG_Parameters::DataObjects_Get_Projection(CSG_Projection &Projection)	cons
 			}
 			else if( p->is_Input() )
 			{
-				if( p->is_DataObject() && p->asDataObject() )
+				if( p->is_DataObject()
+				&&  p->asDataObject() != DATAOBJECT_NOTSET
+				&&  p->asDataObject() != DATAOBJECT_CREATE )
 				{
 					P	= p->asDataObject()->Get_Projection();
 
@@ -1563,7 +1570,9 @@ bool CSG_Parameters::DataObjects_Set_Projection(const CSG_Projection &Projection
 			}
 			else if( p->is_Output() )
 			{
-				if( p->is_DataObject() && p->asDataObject() )
+				if( p->is_DataObject()
+				&&  p->asDataObject() != DATAOBJECT_NOTSET
+				&&  p->asDataObject() != DATAOBJECT_CREATE )
 				{
 					p->asDataObject()->Get_Projection()	= Projection;
 				}
@@ -1619,9 +1628,9 @@ bool CSG_Parameters::Msg_String(bool bOptionsOnly)
 
 	if( Get_String(s, bOptionsOnly) )
 	{
-		SG_UI_Msg_Add_Execution(SG_T("\n"), false);
+		SG_UI_Msg_Add_Execution("\n", false);
 		SG_UI_Msg_Add_Execution(bOptionsOnly ? _TL("Options") : _TL("Parameters"), false);
-		SG_UI_Msg_Add_Execution(SG_T("\n"), false);
+		SG_UI_Msg_Add_Execution("\n", false);
 		SG_UI_Msg_Add_Execution(s, false, SG_UI_MSG_STYLE_01);
 
 		return( true );
@@ -1716,9 +1725,11 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 					{
 						pObject	= p->asList()->asDataObject(j);
 
-						pEntry	= pList->Add_Child(*pList, false); pEntry->Set_Name("INPUT");
+						pEntry	= pList->Add_Child(*pList, false);
 
-						if( pObject->Get_History().Get_Children_Count() > 0 )
+						pEntry->Set_Name(pObject->Get_Name());
+						
+						if( !SG_Get_History_Ignore_Lists() && pObject->Get_History().Get_Children_Count() > 0 )
 						{
 							pEntry->Add_Children(pObject->Get_History());
 						}
