@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: parameters.h 2872 2016-03-30 16:28:26Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -488,6 +488,8 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Range );		}
 
+	virtual bool				Set_Value				(const CSG_String &Value);
+
 	virtual const SG_Char *		asString				(void);
 
 	bool						Set_Range				(double loVal, double hiVal);
@@ -1290,8 +1292,10 @@ public:
 	class CSG_Data_Manager *	Get_Manager				(void)	const;
 
 	const SG_Char *				Get_Identifier			(void)	const;
+	bool						Set_Name				(const CSG_String &Name);
 	const SG_Char *				Get_Name				(void)	const;
 	const SG_Char *				Get_Description			(void)	const;
+	bool						Set_Description			(const CSG_String &Description);
 	CSG_String					Get_Description			(int Flags)								const;
 	CSG_String					Get_Description			(int Flags, const SG_Char *Separator)	const;
 
