@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: res_commands.h 2793 2016-02-16 16:51:24Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -96,10 +96,18 @@ enum ID_COMMANDS
 	ID_CMD_FRAME_TILE_HORZ,
 	ID_CMD_FRAME_TILE_VERT,
 	ID_CMD_FRAME_ARRANGEICONS,
+	ID_CMD_FRAME_UNSPLIT,
+	ID_CMD_FRAME_SPLIT_LEFT,
+	ID_CMD_FRAME_SPLIT_RIGHT,
+	ID_CMD_FRAME_SPLIT_TOP,
+	ID_CMD_FRAME_SPLIT_BOTTOM,
+	ID_CMD_FRAME_SPLIT_ALL_HORZ,
+	ID_CMD_FRAME_SPLIT_ALL_VERT,
 	ID_CMD_FRAME_NEXT,
 	ID_CMD_FRAME_PREVIOUS,
 	ID_CMD_FRAME_CLOSE,
 	ID_CMD_FRAME_CLOSE_ALL,
+	ID_CMD_FRAME_CLOSE_ALL_OTHERS,
 
 	ID_CMD_FRAME_QUIT,
 	ID_CMD_FRAME_HELP,
