@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: view_base.h 2858 2016-03-23 16:05:24Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -72,6 +72,10 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
+#if !defined(_SAGA_MSW)
+#define MDI_TABBED
+#endif
+
 #ifdef MDI_TABBED
 #include <wx/aui/tabmdi.h>
 #define MDI_ChildFrame	wxAuiMDIChildFrame
