@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: view_table_control.cpp 2730 2015-12-16 11:55:46Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -163,6 +163,8 @@ CVIEW_Table_Control::CVIEW_Table_Control(wxWindow *pParent, CSG_Table *pTable, i
 	CreateGrid(0, 0, wxGrid::wxGridSelectRows);
 
 	Update_Table();
+
+	wxGrid::AdjustScrollbars();
 }
 
 //---------------------------------------------------------
@@ -443,6 +445,8 @@ bool CVIEW_Table_Control::_Update_Sorting(int iField, int Direction)
 {
 	if( iField >= 0 && iField < m_pTable->Get_Field_Count() )
 	{
+		m_Cursor	= -1;
+
 		switch( Direction )
 		{
 		default:	m_pTable->Toggle_Index(iField);	break;
@@ -497,15 +501,17 @@ bool CVIEW_Table_Control::_Set_Scroll_Start(int Position, bool bEnforceUpdate)
 //---------------------------------------------------------
 void CVIEW_Table_Control::AdjustScrollbars(void)
 {
-	Freeze();
-	
-	wxGrid::AdjustScrollbars();
-
+	//-----------------------------------------------------
 	m_Scroll_Range	= (GetClientSize().y - GetColLabelSize()) / GetDefaultRowSize();
+//	m_Scroll_Range	= GetGridWindow()->GetClientSize().y / GetDefaultRowSize();
 
 	SetScrollbar(wxVERTICAL, m_Scroll_Start, m_Scroll_Range, _Get_Record_Count());
 
-	Thaw();
+	//-----------------------------------------------------
+	int	Range	= GetGridWindow()->GetVirtualSize().x / GetScrollLineX();
+	int	Thumb	= GetGridWindow()->GetClientSize ().x / GetScrollLineX();
+
+	SetScrollbar(wxHORIZONTAL, GetScrollPos(wxHORIZONTAL), Thumb, Range);
 }
 
 //---------------------------------------------------------
@@ -533,9 +539,9 @@ void CVIEW_Table_Control::On_Key(wxKeyEvent &event)
 {
 	if     ( event.GetKeyCode() == WXK_UP       )
 	{
-		if( GetCursorRow() > 0 )
+		if( GetGridCursorRow() > 0 )
 		{
-			SetGridCursor(GetCursorRow() - 1, GetCursorColumn());
+			SetGridCursor(GetGridCursorRow() - 1, GetGridCursorCol());
 		}
 		else
 		{
@@ -544,9 +550,9 @@ void CVIEW_Table_Control::On_Key(wxKeyEvent &event)
 	}
 	else if( event.GetKeyCode() == WXK_DOWN     )
 	{
-		if( GetCursorRow() < m_Scroll_Range - 1 )
+		if( GetGridCursorRow() < m_Scroll_Range - 1 )
 		{
-			SetGridCursor(GetCursorRow() + 1, GetCursorColumn());
+			SetGridCursor(GetGridCursorRow() + 1, GetGridCursorCol());
 		}
 		else
 		{
@@ -576,9 +582,7 @@ void CVIEW_Table_Control::On_Size(wxSizeEvent &event)//&WXUNUSED(event))
 
 		if( Scroll_Range != m_Scroll_Range )
 		{
-			Freeze();
 			_Update_Records();
-			Thaw();
 		}
 	}
 }
@@ -672,51 +676,46 @@ void CVIEW_Table_Control::On_LClick(wxGridEvent &event)
 //---------------------------------------------------------
 void CVIEW_Table_Control::On_LClick_Label(wxGridEvent &event)
 {
-	if( m_bSelOnly )
+	if( !m_bSelOnly )
 	{
-		// nop
-	}
-	else if( event.GetRow() < 0 )
-	{
-		if( event.GetCol() < 0 && m_pTable->Get_Selection_Count() > 0 )	// deselect everything
+		if( event.GetRow() >= 0 )	// select records
 		{
-			m_pTable->Select();
-
-			Update_Selection();	_Update_Views();
-		}
-	}
-	else // if( event.GetRow() >= 0 )	// select records
-	{
-		if( !event.ControlDown() )
-		{
-			m_pTable->Select();
-
-			if( !event.ShiftDown() || m_Cursor < 0 || m_Cursor >= m_pTable->Get_Count() )
+			if( event.ControlDown() )
 			{
+				m_pTable->Select(_Get_Record(event.GetRow()), true);
+			}
+			else if( !event.ShiftDown() )
+			{
+				m_pTable->Select();	// deselect everything
+
 				m_pTable->Select(_Get_Record(event.GetRow()), false);
 			}
-			else // if( event.ShiftDown() )
+			else if( m_Cursor >= 0 && m_Cursor < m_pTable->Get_Count() )
 			{
-				int	iFirst	= m_Scroll_Start + event.GetRow() <= m_Cursor ? m_Scroll_Start + event.GetRow() : m_Cursor;
-				int	iLast	= m_Scroll_Start + event.GetRow() >  m_Cursor ? m_Scroll_Start + event.GetRow() : m_Cursor;
+				int	iFirst	= m_Scroll_Start + event.GetRow() <= m_Cursor ? m_Scroll_Start + event.GetRow() : m_Cursor + 1;
+				int	iLast	= m_Scroll_Start + event.GetRow() >  m_Cursor ? m_Scroll_Start + event.GetRow() : m_Cursor - 1;
 
 				for(int iRecord=iFirst; iRecord<=iLast; iRecord++)
 				{
-					m_pTable->Select(iRecord, true);
+					m_pTable->Select(m_pTable->Get_Record_byIndex(iRecord)->Get_Index(), true);
 				}
 			}
-		}
-		else // if( event.ControlDown() )
-		{
-			m_pTable->Select(_Get_Record(event.GetRow()), true);
-		}
 
-		Update_Selection();	_Update_Views();
+			Update_Selection();	_Update_Views();
+		}
+		else if( event.GetCol() < 0 )
+		{
+			m_pTable->Select();	// deselect everything
+
+			Update_Selection();	_Update_Views();
+		}
 	}
 
 	m_Cursor	= m_Scroll_Start + event.GetRow();
 
 	SetGridCursor(event.GetRow(), GetGridCursorCol());
+
+	GetGridWindow()->SetFocus();
 }
 
 //---------------------------------------------------------
@@ -733,7 +732,11 @@ void CVIEW_Table_Control::On_LDClick_Label(wxGridEvent &event)
 //---------------------------------------------------------
 bool CVIEW_Table_Control::_Get_DataSource(wxString &Source)
 {
-	if( Source.Find("PGSQL:") == 0 || wxFileExists(Source) )
+	if( Source.Find("PGSQL:" ) == 0
+	||	Source.Find("ftp://" ) == 0
+	||	Source.Find("http://") == 0
+	||	Source.Find("file://") == 0
+	||  wxFileExists(Source) )
 	{
 		return( true );
 	}
