@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_map_dc.cpp 2333 2014-11-10 15:30:41Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -115,7 +115,7 @@ CWKSP_Map_DC::CWKSP_Map_DC(const CSG_Rect &rWorld, const wxRect &rDC, double Sca
 	//-----------------------------------------------------
 	dc_BMP.Create(m_rDC.GetWidth(), m_rDC.GetHeight());
 	dc.SelectObject(dc_BMP);
-	dc.SetBackground(wxBrush(wxColour(m_Background[0], m_Background[1], m_Background[2]), wxSOLID));
+	dc.SetBackground(wxBrush(wxColour(m_Background[0], m_Background[1], m_Background[2]), wxBRUSHSTYLE_SOLID));
 	dc.Clear();
 }
 
