@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_shapes.h 2329 2014-11-05 19:32:43Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -156,7 +156,7 @@ protected:
 
 	virtual void				On_Update_Views			(void);
 
-	virtual void				On_Draw					(CWKSP_Map_DC &dc_Map, bool bEdit);
+	virtual void				On_Draw					(CWKSP_Map_DC &dc_Map, int Flags);
 
 	bool						Get_Class_Color			(CSG_Shape *pShape, int &Color);
 
@@ -164,7 +164,7 @@ protected:
 	void						AttributeList_Set		(CSG_Parameter *pFields, bool bAddNoField);
 
 	CSG_Parameter *				BrushList_Add			(CSG_Parameter *pNode, const CSG_String &Identifier, const CSG_String &Name, const CSG_String &Description);
-	int							BrushList_Get_Style		(int Index);
+	wxBrushStyle				BrushList_Get_Style		(int Index);
 
 	CSG_Parameter *				PenList_Add				(CSG_Parameter *pNode, const CSG_String &Identifier, const CSG_String &Name, const CSG_String &Description);
 	int							PenList_Get_Style		(int Index);
